from typing import Optional, Dict, List

from pydantic import BaseModel

from . import fields


class ItemDetailModel(BaseModel):
    """
    商品详情返回信息
    """

    cat_leaf_name: str = fields.cat_leaf_name_field
    cat_name: str = fields.cat_name_field
    item_url: str = fields.item_url_field
    ju_online_end_time: str = fields.ju_online_end_time_field
    ju_online_start_time: str = fields.ju_online_start_time_field
    ju_pre_show_end_time: str = fields.ju_pre_show_end_time_field
    ju_pre_show_start_time: str = fields.ju_pre_show_start_time_field
    material_lib_type: str = fields.material_lib_type_field
    nick: str = fields.nick_field
    num_iid: str = fields.num_iid_field
    pict_url: str = fields.pict_url_field
    presale_deposit: str = fields.presale_deposit_field
    presale_end_time: str = fields.presale_end_time_field
    presale_start_time: str = fields.presale_start_time_field
    presale_tail_end_time: str = fields.presale_tail_end_time_field
    presale_tail_start_time: str = fields.presale_tail_start_time_field
    provcity: str = fields.provcity_field
    reserve_price: str = fields.reserve_price_field
    seller_id: str = fields.seller_id_field
    small_images: Dict[str, Optional[List[str]]] = fields.small_images_field
    title: str = fields.title_field
    tmall_play_activity_end_time: int = fields.tmall_play_activity_end_time_field
    tmall_play_activity_start_time: int = fields.tmall_play_activity_start_time_field
    user_type: int = fields.user_type_field
    volume: int = fields.volume_field
    zk_final_price: str = fields.zk_final_price_field
    kuadian_promotion_info: Optional[str] = fields.kuadian_promotion_info_field



from typing import Optional

from .base_args import BaseArgs


class ItemDetailArgs(BaseArgs):
    """
    折淘客 全网商品详情接口参数

    :doc https://www.zhetaoke.com/user/open/open_item_info.aspx
    """

    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10001/api/open_item_info.ashx"

    num_iids: str
    # the system will auto fill this value
    sid: Optional[str] = None



import hashlib
import json
from typing import Optional

from structlog.stdlib import BoundLogger

__all__ = ["MobPushBase"]


class MobPushBase(object):
    """
    Mob Push SDK (Base)

    :doc: https://www.mob.com/wiki/detailed/?wiki=MobPushRestAPIfenlei1333&id=136
    """

    s_push_url: str = "http://api.push.mob.com/v3/push/createPush"

    def __init__(self, logger: BoundLogger, app_key: str, app_secret: str):
        """
        :param logger:
        :param app_key: mob app key
        :param app_secret: mob app secret
        """
        self._log = logger
        self._app_key = app_key
        self._app_secret = app_secret

    def compute_sign(self, data: Optional[dict]) -> str:
        """
        计算 mob 的签名

        :param data: 要加密的数据
        :return:
        """
        if data is None:
            str_org = self._app_secret
        else:
            str_org = "%s%s" % (json.dumps(data), self._app_secret)

        return hashlib.md5(str_org.encode("utf-8")).hexdigest()



from typing import List

from pydantic import BaseModel, Field


class GenericItemInfo(BaseModel):
    id: int = Field(..., title="")
    goodsId: str = Field(..., title="")
    title: str = Field(..., title="")
    dtitle: str = Field(..., title="")
    originalPrice: float = Field(..., title="")
    actualPrice: float = Field(..., title="")
    shopType: int = Field(..., title="")
    goldSellers: int = Field(..., title="")
    monthSales: int = Field(..., title="")
    twoHoursSales: int = Field(..., title="")
    dailySales: int = Field(..., title="")
    commissionType: int = Field(..., title="")
    desc: str = Field(..., title="")
    couponReceiveNum: int = Field(..., title="")
    couponLink: str = Field(..., title="")
    couponEndTime: str = Field(..., title="")
    couponStartTime: str = Field(..., title="")
    couponPrice: float = Field(..., title="")
    couponConditions: str = Field(..., title="")
    activityType: int = Field(..., title="")
    createTime: str = Field(..., title="")
    mainPic: str = Field(..., title="")
    marketingMainPic: str = Field(..., title="")
    sellerId: str = Field(..., title="")
    cid: int = Field(..., title="")
    discounts: float = Field(..., title="")
    commissionRate: float = Field(..., title="")
    couponTotalNum: int = Field(..., title="")
    haitao: int = Field(..., title="")
    activityStartTime: str = Field(..., title="")
    activityEndTime: str = Field(..., title="")
    shopName: str = Field(..., title="")
    shopLevel: int = Field(..., title="")
    descScore: float = Field(..., title="")
    brand: int = Field(..., title="")
    brandId: int = Field(..., title="")
    brandName: str = Field(..., title="")
    hotPush: int = Field(..., title="")
    teamName: str = Field(..., title="")
    itemLink: str = Field(..., title="")
    tchaoshi: int = Field(..., title="")

    dsrScore: float = Field(..., title="")
    dsrPercent: float = Field(..., title="")

    shipScore: float = Field(..., title="")
    shipPercent: float = Field(..., title="")

    serviceScore: float = Field(..., title="")
    servicePercent: float = Field(..., title="")

    subcid: List[int] = Field(..., title="")
    nineCid: int = Field(..., title="")
    quanMLink: int = Field(..., title="")
    hzQuanOver: int = Field(..., title="")
    yunfeixian: int = Field(..., title="")
    estimateAmount: int = Field(..., title="")
    freeshipRemoteDistrict: int = Field(..., title="")
    video: str = Field(..., title="")
    tbcid: int = Field(..., title="")


class GenericData(BaseModel):
    list: List[GenericItemInfo] = Field(..., title="")
    totalNum: int = Field(..., title="")
    pageId: str = Field(..., title="")


class GenericResp(BaseModel):
    time: int = Field(..., title="")
    code: int = Field(..., title="")
    msg: str = Field(..., title="")
    data: GenericData = Field(..., title="")



from typing import Optional

from pydantic import BaseModel


class TKLCreateResp(BaseModel):
    """
    参见: https://www.zhetaoke.com/user/open/open_tkl_create.aspx
    参见: https://open.taobao.com/api.htm?docId=31127&docType=2
    """

    #  iOS 14 版本的淘口令
    model: Optional[str] = None
    #  iOS 14 版本的淘口令
    password_simple: Optional[str] = None

    status: Optional[int] = None
    content: Optional[str] = None

    def is_success(self):
        if self.model is not None:
            return True
        return False



from typing import Optional

from .base_args import BaseArgs


class ChannelSaveRecordArgs(BaseArgs):
    """
    淘宝客渠道备案API：用户进行渠道备案，生成新的渠道ID。
    支持渠道备案和会员备案

    :doc https://www.zhetaoke.com/user/open/open_sc_publisher_save.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/open_sc_publisher_save.ashx"

    # 淘宝客邀请渠道的邀请码
    inviter_code: str

    #  代理授权，并登记备案后，返回渠道信息至回调地址
    backurl: str

    # 淘宝客邀请会员的邀请码
    inviter_code_s: Optional[str] = None

    #  淘客授权页面类型
    #  1：电脑版授权页面
    #  0：手机版授权页面
    #  默认值1
    type: Optional[int] = None

    #  渠道备注，此内容建议填写用户唯一标识（比如用户编号，账号等唯一字段），
    #  跟返回的relation_id字段做关联。
    s_note: Optional[str] = None



import os

import pytest

from .gen import *
from .test_shared import get_dtk_sync


def get_app_key_and_secret() -> (str, str):
    app_key = os.getenv("DTK_APP_KEY")
    app_secret = os.getenv("DTK_APP_SECRET")
    return app_key, app_secret


def test_simple():
    dtk = get_dtk_sync()
    args = GoodsNineOpGoodsListArgs(pageId=str(1), pageSize=str(10), nineCid=str(2))
    ret = dtk.goods_nine_op_goods_list(args=args)
    # print(json.dumps(ret, ensure_ascii=False))


def test_super_category():
    dtk = get_dtk_sync()
    ret = dtk.category_get_super_category()
    s = json.dumps(ret, ensure_ascii=False)
    # print(s)


@pytest.mark.asyncio
async def test_async_simple():
    app_key, app_secret = get_app_key_and_secret()
    args = GoodsNineOpGoodsListArgs(pageId=str(1), pageSize=str(10), nineCid=str(2))
    dtk = DtkAsync(app_key=app_key, app_secret=app_secret)
    ret = await dtk.goods_nine_op_goods_list(args=args)
    print(ret)



from typing import Optional

from .base_args import BaseArgs


class JuHuaSuanArgs(BaseArgs):
    """
    聚划算商品API：返回聚划算商品列表，返回佣金≥15%，动态描述分≥4.6的商品列表。

    :doc https://www.zhetaoke.com/user/extend/extend_lingquan_juhuasuan.aspx
    """

    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10001/api/api_all.ashx"

    page: int = 1
    page_size: int = 20
    sort: str = "new"
    cid: Optional[int] = None

    jt: str = "juhuasuan"



from typing import Optional

from .base_args import BaseArgs


class ItemDetailV2Args(BaseArgs):
    """
    全网商品详情API接口:

    返回全网商品详情信息，包含优惠券信息，可用来开发全网搜索等超级功能。

    :doc http://www.zhetaoke.com/user/extend/extend_lingquan_detail.aspx
    """

    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10002/api/api_detail.ashx"

    tao_id: str
    code: Optional[str] = None
    num_iids: Optional[str] = None
    type: Optional[str] = None

    # the system will auto fill this value
    sid: Optional[str] = None



"""
折淘客 开放平台 API

官网: https://www.zhetaoke.com/
API接口: https://www.zhetaoke.com/user/extend/extend_lingquan_default.aspx
"""
from .auth_account_args import AuthAccountArgs  # noqa
from .bang_dan_tui_jian_args import BangDanTuiJianArgs  # noqa
from .batch_item_args import BatchItemsArgs  # noqa
from .batch_item_model import BatchItemModel  # noqa
from .batch_item_resp import BatchItemResp  # noqa
from .channel_account_info_args import ChannelAccountInfoArgs  # noqa
from .channel_id_list_args import ChannelIdListArgs  # noqa
from .channel_invite_code_args import ChannelInviteCodeArgs  # noqa
from .channel_save_record_args import ChannelSaveRecordArgs  # noqa
from .gao_yong_args import GaoYongArgs  # noqa
from .guess_you_like_args import GuessYouLikeArgs  # noqa
from .item_detail_args import ItemDetailArgs  # noqa
from .item_detail_model import ItemDetailModel  # noqa
from .item_detail_v2_args import ItemDetailV2Args  # noqa
from .item_detail_v2_model import ItemDetailV2Model  # noqa
from .item_detail_v2_resp import ItemDetailV2Resp  # noqa
from .ju_hua_suan_args import JuHuaSuanArgs  # noqa
from .new_order_args import NewOrderArgs  # noqa
from .nine_nine_args import NineNineArgs  # noqa
from .order_details_resp import OrderDetailsResp, OrderDto, TkStatusEnum  # noqa
from .search_args import SearchArgs  # noqa
from .suggest_args import SuggestArgs  # noqa
from .tkl_create_args import TKLCreateArgs  # noqa
from .tkl_create_resp import TKLCreateResp  # noqa
from .tmall_chao_shi_args import TMallChaoShiArgs  # noqa
from .tmall_shang_pin_args import TMallShangPinArgs  # noqa
from .ztk import ZTK  # noqa
from .ztk_std import ZTKStd  # noqa
from .ztk_sync import ZTKSync  # noqa



from typing import Optional

from .base_args import BaseArgs


class ChannelInviteCodeArgs(BaseArgs):
    """
    淘宝客邀请码生成API：生成邀请码，然后让用户进行渠道备案，生成新的渠道ID

    :doc https://www.zhetaoke.com/user/open/open_sc_invitecode_get.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/open_sc_invitecode_get.ashx"

    # 渠道推广的物料类型，示例值：common
    relation_app: str

    #  邀请码类型
    #  1 - 渠道邀请，
    #  2 - 渠道裂变，
    #  3 - 会员邀请
    code_type: int

    #  渠道关系ID
    relation_id: Optional[str] = None

    sid: Optional[str] = None



from .gen import *

from .test_shared import get_id, get_dtk_sync, get_goods_id


def test_gen_category_get_super_category():
    dtk = get_dtk_sync()
    ret = dtk.category_get_super_category()
    assert ret["code"] == 0
    print(ret)


def test_goods_price_trend():
    dtk = get_dtk_sync()
    args = GoodsPriceTrendArgs(id=get_id())
    ret = dtk.goods_price_trend(args)
    print(ret)
    assert ret["code"] == 0


def test_goods_get_dtk_search_goods():
    dtk = get_dtk_sync()
    args = GoodsGetDtkSearchGoodsArgs(keyWords="手机", pageId=str(1), pageSize=str(10))
    ret = dtk.goods_get_dtk_search_goods(args)
    print(ret)
    assert ret["code"] == 0


def test_tb_service_get_privilege_link():
    dtk = get_dtk_sync()
    args = TbServiceGetPrivilegeLinkArgs(goodsId=get_goods_id())
    ret = dtk.tb_service_get_privilege_link(args)
    print(ret)
    assert ret["code"] == 0


def test_goods_get_ranking_list():
    dtk = get_dtk_sync()
    args = GoodsGetRankingListArgs(rankType=str(1))
    ret = dtk.goods_get_ranking_list(args)
    assert ret["code"] == 0


def test_goods_get_goods_details():
    dtk = get_dtk_sync()
    args = GoodsGetGoodsDetailsArgs(id=get_id())
    ret = dtk.goods_get_goods_details(args)
    assert ret["code"] == 0


def test_tb_service_get_brand_list():
    dtk = get_dtk_sync()
    args = TbServiceGetBrandListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.tb_service_get_brand_list(args)
    assert ret["code"] == 0
    print(ret)


def test_goods_nine_op_goods_list():
    dtk = get_dtk_sync()
    args = GoodsNineOpGoodsListArgs(pageId=str(1), pageSize=str(10), nineCid=str(1))
    ret = dtk.goods_nine_op_goods_list(args)
    print(ret)
    assert ret["code"] == 0


def test_tb_service_get_tb_service():
    dtk = get_dtk_sync()
    args = TbServiceGetTbServiceArgs(pageNo=str(1), pageSize=str(10), keyWords="苹果")
    ret = dtk.tb_service_get_tb_service(args)
    print(ret)
    assert ret["code"] == 0


def test_category_get_top100():
    dtk = get_dtk_sync()
    ret = dtk.category_get_top100()
    print(ret)
    assert ret["code"] == 0


def test_category_ddq_goods_list():
    dtk = get_dtk_sync()
    args = CategoryDdqGoodsListArgs(roundTime="2020-12-18 15:00:00")
    ret = dtk.category_ddq_goods_list(args)
    print(ret)



from typing import List, Any

from pydantic import BaseModel


class BatchItemContentItem(BaseModel):
    code: str
    type_one_id: str
    tao_id: str
    title: str
    jianjie: str
    pict_url: str
    user_type: str
    seller_id: str
    shop_dsr: str
    volume: str
    size: str
    quanhou_jiage: str
    date_time_yongjin: str
    tkrate3: str
    yongjin_type: str
    coupon_id: str
    coupon_start_time: str
    coupon_end_time: str
    coupon_info_money: str
    coupon_total_count: str
    coupon_remain_count: str
    coupon_info: str
    juhuasuan: str
    taoqianggou: str
    haitao: str
    jiyoujia: str
    jinpaimaijia: str
    pinpai: str
    pinpai_name: str
    yunfeixian: str
    nick: str
    small_images: str
    white_image: str
    tao_title: str
    provcity: str
    shop_title: str
    zhibo_url: str
    sellCount: str
    commentCount: str
    favcount: str
    score1: str
    score2: str
    score3: str
    creditLevel: str
    shopIcon: str
    pcDescContent: str
    item_url: str
    category_id: str
    category_name: str
    level_one_category_id: str
    level_one_category_name: str
    tkfee3: str
    biaoqian: str
    tag: str
    date_time: str
    presale_discount_fee_text: str
    presale_tail_end_time: str
    presale_tail_start_time: str
    presale_end_time: str
    presale_start_time: str
    presale_deposit: str
    min_commission_rate: str


class BatchItemResp(BaseModel):
    status: int
    content: List[Any]



import hashlib
import random
import time

__all__ = ["DtkBase"]


class DtkBase(object):
    """
    大淘客基础请求类
    """

    def __init__(self, app_key: str, app_secret: str):
        self._app_key = app_key
        self._app_secret = app_secret

    @property
    def app_key(self) -> str:
        return self._app_key

    @property
    def app_secret(self) -> str:
        return self._app_secret

    def merge_args(self, d: dict, version: str) -> dict:
        d = {key: value for key, value in d.items() if value is not None}

        d["appKey"] = self._app_key
        d["version"] = version

        # https://www.dataoke.com/pmc/open-gz.html?id=41
        nonce = str(random.randrange(100_000, 999_999, 1))
        timer = int(time.time() * 1000)
        key = self._app_secret
        d["nonce"] = nonce
        d["timer"] = timer
        s = f"appKey={self._app_key}&timer={timer}&nonce={nonce}&key={key}"
        h = hashlib.md5(s.encode())
        d["signRan"] = h.hexdigest().upper()
        return d



"""
代码生成模块测试
"""

import os
import sys

from .gen import *
from .test_shared import get_id, get_dtk_sync, get_goods_id, get_uland_url


def convert_name_to_py_class_name(name: str) -> str:
    parts = name.split("_")
    out = "".join(map(lambda x: x.capitalize(), parts))
    return f"{out}Resp"


def gen_with_class_name(class_name: str, data: dict) -> str:
    fields = []
    sub_codes = []
    for name, value in data.items():
        typ = type(value)
        if typ is str:
            fields.append(f"""    {name}: Optional[str] = Field(None)""")
        elif typ is int:
            fields.append(f"""    {name}: Optional[int] = Field(None)""")
        elif typ is float:
            fields.append(f"""    {name}: Optional[float] = Field(None)""")
        elif typ is dict:
            sub_name, sub_code = gen_sub_field(class_name, name, value)
            fields.append(f"""    {name}: Optional[{sub_name}] = Field(None)""")
            sub_codes.append(sub_code)
        elif typ is list:
            if len(value) >= 1:
                if type(value[0]) == dict:
                    sub_name, sub_code = gen_sub_field(class_name, name, value[0])
                    fields.append(
                        f"""    {name}: Optional[List[{sub_name}]] = Field(None)"""
                    )
                    sub_codes.append(sub_code)
                elif type(value[0]) == str:
                    fields.append(f"""    {name}: Optional[List[str]] = Field(None)""")
                elif type(value[0]) == int:
                    fields.append(f"""    {name}: Optional[List[int]] = Field(None)""")
                else:
                    print(f"{type(value[0])} is not handled")
                    sys.exit(3)
            else:
                fields.append(f"""    {name}: Optional[list] = Field(None)""")
        else:
            print(f"未知的类型: {typ=}")
            sys.exit(1)
    field_code = "\n".join(fields)
    sub_field_code = "\n".join(sub_codes)

    return f"""
{sub_field_code}
class {class_name}(BaseModel):
{field_code}
"""


# return value:
# 1st is sub class name
# 2nd is code
def gen_sub_field(class_name: str, field_name: str, data: dict) -> (str, str):
    sub_name = f"{class_name}{field_name.capitalize()}"

    class_dt = gen_with_class_name(sub_name, data)

    return sub_name, class_dt


def gen_one_data(name: str, data: dict) -> str:
    class_name = convert_name_to_py_class_name(name)

    fields = []
    sub_codes = []
    for name, value in data.items():
        typ = type(value)
        if typ is str:
            fields.append(f"""    {name}: Optional[str] = Field(None)""")
        elif typ is int:
            fields.append(f"""    {name}: Optional[Union[int, float]] = Field(None)""")
        elif typ is float:
            fields.append(f"""    {name}: Optional[float] = Field(None)""")
        elif typ is dict:
            sub_name, sub_code = gen_sub_field(class_name, name, value)
            fields.append(f"""    {name}: Optional[{sub_name}] = Field(None)""")
            sub_codes.append(sub_code)
        elif typ is list:
            if len(value) >= 1:
                if type(value[0]) == dict:
                    sub_name, sub_code = gen_sub_field(class_name, name, value[0])
                    fields.append(
                        f"""    {name}: Optional[List[{sub_name}]] = Field(None)"""
                    )
                    sub_codes.append(sub_code)
                elif type(value[0]) == str:
                    fields.append(f"""    {name}: Optional[List[str]] = Field(None)""")
                elif type(value[0]) == int:
                    fields.append(f"""    {name}: Optional[List[int]] = Field(None)""")
                else:
                    print(f"{type(value[0])} is not handled")
                    sys.exit(3)
            else:
                fields.append(f"""    {name}: Optional[list] = Field(None)""")
        else:
            sys.exit(1)

    field_code = "\n".join(fields)
    sub_field_code = "\n".join(sub_codes)

    return f"""
{sub_field_code}
class {class_name}(BaseModel):
{field_code}
"""


def write_to_file(code: str):
    out_file = os.path.join(os.path.dirname(__file__), "dt_resp_v2.py")
    with open(out_file, "a") as fp:
        fp.write(code)


def test_gen_category_get_super_category():
    dtk = get_dtk_sync()
    ret = dtk.category_get_super_category()
    assert ret["code"] == 0
    o = gen_one_data("category_get_super_category", ret["data"][0])
    write_to_file(o)


def test_goods_price_trend():
    dtk = get_dtk_sync()
    args = GoodsPriceTrendArgs(id=get_id())
    ret = dtk.goods_price_trend(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_price_trend", ret["data"])
    write_to_file(o)


def test_goods_dtk_search():
    dtk = get_dtk_sync()
    args = GoodsGetDtkSearchGoodsArgs(keyWords="手机", pageId=str(3), pageSize=str(10))
    ret = dtk.goods_get_dtk_search_goods(args)
    assert ret["code"] == 0
    o = gen_one_data("goods_get_dtk_search_goods", ret["data"])
    write_to_file(o)


def test_tb_service_get_privilege_link():
    dtk = get_dtk_sync()
    args = TbServiceGetPrivilegeLinkArgs(goodsId=get_goods_id())
    ret = dtk.tb_service_get_privilege_link(args)
    assert ret["code"] == 0
    o = gen_one_data("tb_service_get_privilege_link", ret["data"])
    write_to_file(o)


def test_goods_get_ranking_list():
    dtk = get_dtk_sync()
    args = GoodsGetRankingListArgs(rankType=str(1))
    ret = dtk.goods_get_ranking_list(args)
    assert ret["code"] == 0
    o = gen_one_data("goods_get_ranking_list", ret["data"][0])
    write_to_file(o)


def test_goods_get_goods_details():
    dtk = get_dtk_sync()
    args = GoodsGetGoodsDetailsArgs(id=get_id())
    ret = dtk.goods_get_goods_details(args)
    assert ret["code"] == 0
    o = gen_one_data("goods_get_goods_details", ret["data"])
    write_to_file(o)


def test_tb_service_get_brand_list():
    dtk = get_dtk_sync()
    args = TbServiceGetBrandListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.tb_service_get_brand_list(args)
    assert ret["code"] == 0
    o = gen_one_data("tb_service_get_brand_list", ret["data"][0])
    write_to_file(o)


def test_goods_nine_op_goods_list():
    dtk = get_dtk_sync()
    args = GoodsNineOpGoodsListArgs(pageId=str(1), pageSize=str(10), nineCid=str(1))
    ret = dtk.goods_nine_op_goods_list(args)
    assert ret["code"] == 0
    o = gen_one_data("goods_nine_op_goods_list", ret["data"])
    write_to_file(o)


def test_tb_service_get_tb_service():
    dtk = get_dtk_sync()
    args = TbServiceGetTbServiceArgs(pageNo=str(1), pageSize=str(10), keyWords="苹果")
    ret = dtk.tb_service_get_tb_service(args)
    assert ret["code"] == 0
    o = gen_one_data("tb_service_get_tb_service", ret["data"][0])
    write_to_file(o)


def test_category_get_top100():
    dtk = get_dtk_sync()
    ret = dtk.category_get_top100()
    print(ret["data"])
    assert ret["code"] == 0
    o = gen_one_data("category_get_top100", ret["data"])
    write_to_file(o)


def test_goods_get_goods_list():
    dtk = get_dtk_sync()
    args = GoodsGetGoodsListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.goods_get_goods_list(args)
    print(ret["data"]["list"][0])
    assert ret["code"] == 0
    o = gen_one_data("goods_get_goods_list", ret["data"]["list"][0])
    write_to_file(o)


def test_goods_list_super_goods():
    dtk = get_dtk_sync()
    args = GoodsListSuperGoodsArgs(
        pageId=str(1), pageSize=str(10), keyWords="iOS", type=str(0)
    )
    ret = dtk.goods_list_super_goods(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_list_super_goods", ret["data"]["list"][0])
    write_to_file(o)


def test_goods_list_similer_goods_by_open():
    dtk = get_dtk_sync()
    args = GoodsListSimilerGoodsByOpenArgs(id=str(get_id()))
    ret = dtk.goods_list_similer_goods_by_open(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_list_similer_goods_by_open", ret["data"][0])
    write_to_file(o)


def test_goods_search_suggestion():
    dtk = get_dtk_sync()
    args = GoodsSearchSuggestionArgs(keyWords="手机", type=str(1))
    ret = dtk.goods_search_suggestion(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_search_suggestion", ret["data"][0])
    write_to_file(o)


def test_goods_activity_catalogue():
    dtk = get_dtk_sync()
    ret = dtk.goods_activity_catalogue()
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_activity_catalogue", ret["data"][0])
    write_to_file(o)


def test_goods_activity_goods_list():
    dtk = get_dtk_sync()
    # todo impl dtk.goods_activity_goods_list()


def test_goods_topic_catalogue():
    dtk = get_dtk_sync()
    ret = dtk.goods_topic_catalogue()
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_topic_catalogue", ret["data"][0])
    write_to_file(o)


def test_goods_topic_goods_list():
    dtk = get_dtk_sync()
    # args = GoodsTopicGoodsListArgs()
    # ret = dtk.goods_topic_goods_list()


def test_category_ddq_goods_list():
    dtk = get_dtk_sync()
    args = CategoryDdqGoodsListArgs()
    ret = dtk.category_ddq_goods_list(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("category_ddq_goods_list", ret["data"])
    write_to_file(o)


def test_tb_service_parse_taokouling():
    dtk = get_dtk_sync()
    args = TbServiceParseTaokoulingArgs(content="1￥uFkCciFmKQH￥/")
    ret = dtk.tb_service_parse_taokouling(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("tb_service_parse_taokouling", ret["data"])
    write_to_file(o)


def test_tb_service_creat_taokouling():
    dtk = get_dtk_sync()
    args = TbServiceCreatTaokoulingArgs(text="hello", url=get_uland_url())
    ret = dtk.tb_service_creat_taokouling(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("tb_service_creat_taokouling", ret["data"])
    write_to_file(o)


def test_goods_exclusive_goods_list():
    dtk = get_dtk_sync()
    args = GoodsExclusiveGoodsListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.goods_exclusive_goods_list(args)
    print(ret)
    assert ret["code"] == 0
    o = gen_one_data("goods_exclusive_goods_list", ret["data"]["list"][0])
    write_to_file(o)


def test_goods_explosive_goods_list():
    dtk = get_dtk_sync()
    args = GoodsExplosiveGoodsListArgs(pageId=str(1), pageSize=str(10))
    ret = dtk.goods_explosive_goods_list(args)
    assert ret["code"] == 0
    o = gen_one_data("goods_explosive_goods_list", ret["data"]["list"][0])
    write_to_file(o)


def test_delanys_brand_get_goods_list():
    dtk = get_dtk_sync()
    args = DelanysBrandGetGoodsListArgs(
        brandId="30844", pageId=str(1), pageSize=str(10)
    )
    ret = dtk.delanys_brand_get_goods_list(args)
    o = gen_one_data("delanys_brand_get_goods_list", ret["data"]["list"][0])
    write_to_file(o)


def test_slot_code():
    slot = f"""
CategoryGetTbTopicListResp = Any
GoodsActivityGoodsListResp = Any
GoodsFirstOrderGiftMoneyResp = Any
GoodsFriendsCircleListResp = Any
GoodsGetCollectionListResp = Any
GoodsGetNewestGoodsResp = Any
GoodsGetOwnerGoodsResp = Any
GoodsGetStaleGoodsByTimeResp = Any
GoodsLivematerialGoodsListResp = Any
GoodsPullGoodsByTimeResp = Any
GoodsTopicCatalogue = Any
GoodsTopicGoodsListResp = Any
TbServiceActivityLinkResp = Any
TbServiceGetOrderDetailsResp = Any
TbServiceParseContentResp = Any
TbServiceTwdToTwdResp = Any
"""
    write_to_file(slot)



from typing import Optional

from .base_args import BaseArgs


class ChannelIdListArgs(BaseArgs):
    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10001/api/open_sc_publisher_get.ashx"

    info_type: int
    """
    类型，必选 1:渠道信息；2:会员信息
    """

    relation_id: Optional[int] = None
    """
    渠道备案 - 渠道关系ID
    """

    special_id: Optional[int] = None
    """
    会员运营ID
    """

    external_id: Optional[str] = None
    """
    淘宝客外部用户标记，如自身系统账户ID；微信ID等
    """

    page_no: int = 1
    """
    第几页
    """

    page_size: int = 20
    """
    每页大小
    """

    relation_app: str = "common"
    """
    渠道推广的物料类型，示例值：common
    """

    sid: str = ""
    """
    对应的淘客账号授权ID
    """



import asyncio
import logging
from datetime import datetime
from typing import Set, Tuple

from .api_async import DtkAsyncApi
from .gen import *
from ..tbk_api import TbkItemInfo, TbkBrandInfo

__all__ = ["DtkStdApi"]


class DtkStdApi(object):
    """
    大淘客标准化 接口
    """

    def __init__(self, **kwargs):
        self._api = DtkAsyncApi(**kwargs)

    async def gao_yong(
        self, args: TbServiceGetPrivilegeLinkArgs
    ) -> Optional[TbkItemInfo]:
        info = await self._api.tb_service_get_privilege_link(args)
        t = await self.get_goods_detail(args.goodsId)

        t.coupon_link = info.couponClickUrl
        t.coupon_start_time = info.couponStartTime
        t.coupon_end_time = info.couponEndTime
        t.coupon_total_num = int(info.couponTotalCount)
        t.coupon_recv_num = int(info.couponTotalCount) - int(info.couponRemainCount)

        return t

    async def get_brand_goods(self, brand_id: str, page_id: int) -> List[TbkItemInfo]:
        """
        获取超值大牌的商品列表
        """
        args = DelanysBrandGetGoodsListArgs(
            brandId=brand_id, pageId=str(page_id), pageSize="20"
        )
        data_list = await self._api.delanys_brand_get_goods_list(args)
        if data_list is None:
            return []
        tao_ids = []
        for data in data_list:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def get_brand_list(self, page_id: int) -> List[TbkBrandInfo]:
        """
        获取品牌列表
        :param page_id: 第几页 从 1 开始计数
        """
        args = TbServiceGetBrandListArgs(pageId=str(page_id), pageSize=str(20))
        data_list = await self._api.tb_service_get_brand_list(args)
        if data_list is None:
            return []

        def convert_type(one: TbServiceGetBrandListResp) -> TbkBrandInfo:
            sales = 0 if one.sales2h is None else one.sales2h
            return TbkBrandInfo(
                brand_id=str(one.brandId),
                brand_name=one.brandName,
                brand_logo=one.brandLogo,
                brand_desc=one.brandDesc,
                sales_2h=sales,
            )

        return list(map(convert_type, data_list))

    async def get_goods_detail(self, tao_id: str) -> Optional[TbkItemInfo]:
        args = GoodsGetGoodsDetailsArgs(id="", goodsId=tao_id)
        data = await self._api.goods_get_goods_details(args)
        if data is None:
            return None
        return self.convert_to_item_info(data)

    async def get_multi_goods_detail(self, tao_ids: List[str]) -> List[TbkItemInfo]:
        if len(tao_ids) == 0:
            return []
        future_list = map(self.get_goods_detail, tao_ids)
        ret_list, pending = await asyncio.wait(
            future_list
        )  # type: Set[asyncio.Task], Any
        data_list = list(map(lambda x: x.result(), iter(ret_list)))
        return list(filter(lambda x: x is not None, data_list))

    async def goods_explosive_goods_list(
        self, args: GoodsExplosiveGoodsListArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_explosive_goods_list(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def goods_exclusive_goods_list(
        self, args: GoodsExclusiveGoodsListArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_exclusive_goods_list(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def goods_nine_op_goods_list(
        self, args: GoodsNineOpGoodsListArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_nine_op_goods_list(args)
        ret = ret.list
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def category_ddq_goods_list(
        self, args: CategoryDdqGoodsListArgs
    ) -> Optional[Tuple[List[TbkItemInfo], List[CategoryDdqGoodsListRespRoundslist]]]:
        result = await self._api.category_ddq_goods_list(args)
        ret = result.goodsList
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids), result.roundsList

    async def goods_get_ranking_list(
        self, args: GoodsGetRankingListArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_get_ranking_list(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def goods_list_super_goods(
        self, args: GoodsListSuperGoodsArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_list_super_goods(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def goods_list_similer_goods_by_open(
        self, args: GoodsListSimilerGoodsByOpenArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_list_similer_goods_by_open(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def goods_get_goods_list(
        self, args: GoodsGetGoodsListArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_get_goods_list(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def goods_get_dtk_search_goods(
        self, args: GoodsGetDtkSearchGoodsArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.goods_get_dtk_search_goods(args)
        ret = ret.list
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(data.goodsId)
        return await self.get_multi_goods_detail(tao_ids)

    async def tb_service_get_tb_service(
        self, args: TbServiceGetTbServiceArgs
    ) -> Optional[List[TbkItemInfo]]:
        ret = await self._api.tb_service_get_tb_service(args)
        if ret is None:
            return None
        tao_ids = []
        for data in ret:
            tao_ids.append(str(data.item_id))
        return await self.get_multi_goods_detail(tao_ids)

    @staticmethod
    def convert_to_item_info(data: GoodsGetGoodsDetailsResp) -> TbkItemInfo:
        logger = logging.getLogger("root")
        try:
            pics = json.loads(data.detailPics)
            tao_details = list(map(lambda x: x["img"], pics))
        except json.JSONDecodeError as e:  # 吃掉这个异常
            logger.error(f"decode pic failed: {e}")
            tao_details = []

        def convert_to_time(s: str) -> Optional[datetime]:
            try:
                return datetime.fromisoformat(s)
            except ValueError as err:
                logger.error(f"convert to time failed: {err}")
                return None

        return TbkItemInfo(
            tao_id=data.goodsId,
            tao_img=data.mainPic,
            tao_link=data.itemLink,
            tao_details=tao_details,
            title_long=data.title,
            title_short=data.dtitle,
            price_origin=data.originalPrice,
            price_actual=data.actualPrice,
            price_coupon=data.couponPrice,
            seller_id=data.sellerId,
            seller_name=data.shopName,
            seller_logo=data.shopLogo,
            seller_level=data.shopLevel,
            score_dsr=data.dsrScore,
            score_ship=data.shipScore,
            score_service=data.serviceScore,
            percent_dsr=data.dsrPercent,
            percent_ship=data.shipPercent,
            percent_service=data.servicePercent,
            commission_rate=(data.commissionRate / 100.0),
            commission_money=(data.actualPrice / 100.0 * data.commissionRate),
            sale_month=data.monthSales,
            sale_day=data.dailySales,
            sale_two_hours=data.twoHoursSales,
            coupon_start_time=convert_to_time(data.couponStartTime),
            coupon_end_time=convert_to_time(data.couponEndTime),
            coupon_total_num=data.couponTotalNum,
            coupon_recv_num=data.couponReceiveNum,
            coupon_link=data.couponLink,
            yun_fei_xian=data.yunfeixian > 0,
        )



import pytest

from .api_async import DtkAsyncApi
from .api_std import DtkStdApi
from .gen import GoodsNineOpGoodsListArgs, GoodsListSuperGoodsArgs
from .test_shared import get_app_key_and_secret


@pytest.mark.asyncio
async def test_multi():
    app_key, secret = get_app_key_and_secret()

    args = GoodsNineOpGoodsListArgs(pageId=str(1), pageSize="20", nineCid="1")
    dtk = DtkAsyncApi(app_key=app_key, app_secret=secret)
    ret = await dtk.goods_nine_op_goods_list(args)
    tao_ids = []
    for item in ret.list:
        tao_ids.append(item.goodsId)

    std = DtkStdApi(app_key=app_key, app_secret=secret)
    ret = await std.get_multi_goods_detail(tao_ids)
    print(ret)


@pytest.mark.asyncio
async def test_super_search():
    app_key, secret = get_app_key_and_secret()

    a1 = GoodsListSuperGoodsArgs(pageId="1", pageSize="20", keyWords="裤子", type="0")
    a2 = GoodsListSuperGoodsArgs(
        pageId="1", pageSize="20", keyWords="裤子", type="0", sort="total_sales_asc"
    )
    a3 = GoodsListSuperGoodsArgs(
        pageId="1", pageSize="20", keyWords="裤子", type="0", sort="price_asc"
    )

    dtk = DtkStdApi(app_key=app_key, app_secret=secret)
    for args in [a1, a2]:
        j = await dtk.goods_list_super_goods(args)
        assert j is not None



from typing import Literal, Union, Optional

import jwt
from pydantic import BaseModel, Field

__all__ = [
    "AppleConfig",
    "AppleSignInDecoded",
    "AppleSignInFailureRet",
    "AppleSignInSuccessRet",
]


class AppleConfig(BaseModel):
    """
    苹果登陆的配置项目
    """

    key_id: str = Field(
        ...,
        title="the private key id",
        description="[find on apple developer portal -> keys -> key-detail page]",
    )
    private_key: str = Field(
        ...,
        title="the private key content [.p8 file]",
        description="downloaded when the key generate,you can regenerate the key on apple developer portal -> keys",
    )
    team_id: str = Field(
        ..., title="the apple team id", description="view on apple developer portal"
    )
    bundle_id: str = Field(..., title="the app's bundle id")


class AppleSignInFailureRet(BaseModel):
    error: Optional[str] = Field(None, title="请求失败的原因")


class AppleSignInSuccessRet(BaseModel):
    """
    doc: https://developer.apple.com/documentation/sign_in_with_apple/tokenresponse
    """

    access_token: str = Field(
        ...,
        title="A token used to access allowed data",
        description="Currently, no data set has been defined for access.(Reserved for future use)",
    )
    expires_in: int = Field(
        ..., title="The amount of time, in seconds, before the access token expires."
    )
    id_token: str = Field(
        ..., title="A JSON Web Token that contains the user’s identity information."
    )
    refresh_token: str = Field(
        ...,
        title="The refresh token used to regenerate new access tokens",
        description="Store this token securely on your server.",
    )
    token_type: str = Field(
        ..., title="The type of access token.", description="It will always be bearer."
    )

    @property
    def decoded_id_token(self) -> Optional["AppleSignInDecoded"]:
        decoded = jwt.decode(self.id_token, "", verify=False)
        if isinstance(decoded, dict):
            return AppleSignInDecoded(**decoded)
        else:
            return None


class AppleSignInDecoded(BaseModel):
    """
    doc:
    https://developer.apple.com/documentation/sign_in_with_apple/sign_in_with_apple_rest_api/authenticating_users_with_sign_in_with_apple
    """

    iss: str = Field(
        ...,
        title="",
        description="""
    The issuer registered claim identifies the principal
    that issued the identity token.

    Since Apple generates the token,
    the value is https://appleid.apple.com.
    """,
    )

    sub: str = Field(
        ...,
        title="",
        description="""
    The subject registered claim identifies the principal
    that is the subject of the identity token.

    Since this token is meant for your application,
    the value is the unique identifier for the user.
    """,
    )

    aud: str = Field(
        ...,
        title="",
        description="""
    The audience registered claim identifies the recipient
    for which the identity token is intended.

    Since the token is meant for your application,
    the value is the client_id from your developer account.
    """,
    )

    iat: str = Field(
        ...,
        title="iat",
        description="""
    The issued at registered claim indicates the time
    at which Apple issued the identity token,

    in terms of the number of seconds since Epoch, in UTC.
    """,
    )

    exp: str = Field(
        ...,
        title="The expiration time",
        description="""
The expiration time registered identifies the time on
or after which the identity token will expire,
in terms of number of seconds since Epoch, in UTC.

The value must be greater than the
current date/time when verifying the token.
    """,
    )

    email: str = Field(
        ...,
        title="A String value representing the user’s email address.",
        description="""
    The email address will be either
    the user’s real email address or the proxy address,

    depending on their status private email relay service.
                       """,
    )

    email_verified: Union[Literal["true"], Literal["false"], bool] = Field(
        ...,
        title="A String or Boolean value that indicates whether the service has verified the email.",
        description="""
The value of this claim is always true, because the servers
 only return verified email addresses.
The value can either be a String (”true”) or a Boolean (true).""",
    )

    is_private_email: Union[Literal["true"], Literal["false"], bool] = Field(
        ...,
        title="A String or Boolean value that indicates whether the email shared by the user is the proxy address",
        description="""
    The value can either be a String (”true” or “false”)
    or a Boolean (true or false).
""",
    )

    real_user_status: Optional[int] = Field(
        None,
        title="An Integer value that indicates whether the user appears to be a real person.",
        description="""\
Use the value of this claim to mitigate fraud.
The possible values are:
0 (or Unsupported). 1 (or Unknown), 2 (or LikelyReal).
For more information, see ASUserDetectionStatus.
This claim is present only on iOS 14 and later,
macOS 11 and later, watchOS 7 and later, tvOS 14 and later;
the claim is not present or supported for web-based apps.""",
    )

    nonce: Optional[str] = Field(
        None,
        title="A String value used to associate a client session and the identity token",
        description="""\
This value is used to mitigate replay attacks and is present
only if passed during the authorization request.""",
    )

    nonce_supported: Optional[bool] = Field(
        None,
        title="A Boolean value that indicates whether the transaction is on a nonce-supported platform.",
        description="""\
If you sent a nonce in the authorization request
but do not see the nonce claim in the identity token,
check this claim to determine how to proceed.

If this claim returns true,
you should tream nonce as mandatory and fail the transaction;
otherwise, you can proceed treating the nonce as options.""",
    )



from typing import List, Dict

from pydantic import BaseModel, Field

__all__ = ["UserSellerGetArgs"]


class UserSellerGetArgs(BaseModel):
    """
    查询卖家用户信息

    doc: https://open.taobao.com/api.htm?docId=21349&docType=2
    """

    session: str = Field(..., title="session key")
    fields: List[str] = Field(None, title="需要返回的字段列表，可选值为返回示例值中的可以看到的字段")
    method: str = Field("taobao.user.seller.get", title="固定值")

    def to_dict(self) -> Dict[str, str]:
        d = self.dict()
        d["fields"] = ",".join(d["fields"])
        return d



from typing import Optional

from .base_args import BaseArgs


class TKLCreateArgs(BaseArgs):
    """
    淘口令生成API：二合一链接、长链接、短链接等各种淘宝高佣链接，生成淘口令

    :doc https://www.zhetaoke.com/user/open/open_tkl_create.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/open_tkl_create.ashx"

    # 口令跳转目标页，如：https://uland.taobao.com/，必须以https开头，
    # 可以是二合一链接、长链接、短链接等各种淘宝高佣链接；
    # 支持渠道备案链接。请注意，该参数需要进行Urlencode编码后传入。。
    #
    # 重要的事情说三遍：
    # 该参数需要进行Urlencode编码！
    # 该参数需要进行Urlencode编码！
    # 该参数需要进行Urlencode编码！
    url: str

    # taobao_appkey，自己淘客账号下，某个应用的appkey。
    taobao_appkey: str

    # taobao_appsecret，自己淘客账号下，某个应用的appsecret。
    taobao_appsecret: str

    # 口令弹框logoURL
    # 如：https://img.alicdn.com/bao/uploaded/i2.jpg_200x200.jpg
    logo: Optional[str] = None

    #  口令弹框内容，长度大于5个字符，如：美美小编精心推荐。
    #  尽量不要带特殊符号或特殊词，否则生成的淘口令手淘里可能打不开。
    text: str = "美美的小编精心推荐"

    #  值为1或者2，
    #  表示返回淘宝联盟请求地址，
    #  大家拿到地址后再用自己的服务器二次请求即可获得最终结果，
    #
    #  值为1返回http链接，
    #  值为2返回https安全链接，
    #  值为0表示直接返回淘口令最终结果。
    signurl: int = 0

    # 此字段只对signurl=0有效，signurl=1或2时，返回联盟请求地址。
    #
    # 生成淘口令结果类型，
    # type=0表示只返回淘口令，
    # type=1表示返回官方原始淘口令文案，支持IOS14版本。
    #
    # on iOS should use type = 1
    type: int = 0

    sid: str = ""



from pydantic import BaseModel, Field

__all__ = ["TimeGetResp"]


class TimeGetResp(BaseModel):
    """
    获取淘宝系统当前时间

    doc: https://open.taobao.com/api.htm?docId=120&docType=2
    """

    time: str = Field(..., title="时间")
    request_id: str = Field(..., title="请求ID")



from typing import Optional

from pydantic import BaseModel, Field

__all__ = ["TopAuthTokenCreateArgs"]


class TopAuthTokenCreateArgs(BaseModel):
    """
    获取Access Token

    doc: https://open.taobao.com/api.htm?docId=25388&docType=2
    """

    code: Optional[str] = Field(None, title="授权code，grantType==authorization_code 时需要")

    uuid: Optional[str] = Field(None, title="与生成code的uuid配对")

    method: str = Field("taobao.top.auth.token.create", title="固定值")



from typing import Optional

from pydantic import BaseModel, Field

__all__ = ["TBKScPublisherInfoSaveArgs"]


class TBKScPublisherInfoSaveArgs(BaseModel):
    """
    淘宝客-公用-私域用户备案

    doc: https://open.taobao.com/api.htm?docId=37988&docType=2
    """

    session: str = Field(
        None,
        title="用户登录授权成功后，TOP颁发给应用的授权信息",
        description="""
当此API的标签上注明：“需要授权”，则此参数必传；
“不需要授权”，则此参数不需要传；“可选授权”，则此参数为可选
""",
    )

    inviter_code: str = Field(..., title=" 渠道备案 - 淘宝客邀请渠道的邀请码")

    info_type: int = Field(1, title="类型，必选 默认为1:")

    target_app_key: Optional[str] = Field(
        None, title="被调用的目标AppKey，仅当被调用的API为第三方ISV提供时有效"
    )
    partner_id: Optional[str] = Field(None, title="合作伙伴身份标识")

    ###########################################
    relation_from: Optional[str] = Field(None, title="渠道备案 - 来源，取链接的来源")

    offline_scene: Optional[int] = Field(
        None, title="渠道备案 - 线下场景信息，1 - 门店，2- 学校，3 - 工厂，4 - 其他"
    )

    online_scene: Optional[int] = Field(
        None, title="渠道备案 - 线上场景信息，1 - 微信群，2- QQ群，3 - 其他"
    )

    note: Optional[str] = Field(None, title="媒体侧渠道备注")

    register_info: Optional[str] = Field(
        None,
        title="线下备案注册信息",
        description="""
    # 线下备案注册信息,字段包含:
    # 电话号码(phoneNumber，必填)
    # 省(province,必填)
    # 市(city,必填)
    # 区县街道(location,必填)
    # 详细地址(detailAddress,必填)
    # 经营类型(career,线下个人必填)
    # 店铺类型(shopType,线下店铺必填)
    # 店铺名称(shopName,线下店铺必填)
    # 店铺证书类型(shopCertifyType,线下店铺选填)
    # 店铺证书编号(certifyNumber,线下店铺选填)
    """,
    )

    simplify: bool = Field(
        False, title="是否采用精简JSON返回格式", description="仅当format=json时有效，默认值为：false"
    )

    method: str = Field("taobao.tbk.sc.publisher.info.save")



from .product_get import ProductGetArgs  # noqa
from .tbk_sc_publisher_info_save import TBKScPublisherInfoSaveArgs  # noqa
from .time_get import TimeGetArgs  # noqa
from .top_auth_token_create import TopAuthTokenCreateArgs  # noqa
from .user_seller_get import UserSellerGetArgs  # noqa



from typing import Optional

from .base_args import BaseArgs


class NineNineArgs(BaseArgs):
    """
    9.9元商品API：返回购买价格≤9.9元的商品列表，返回佣金≥15%，动态描述分≥4.6的商品列表。

    :doc https://www.zhetaoke.com/user/extend/extend_lingquan_jiu.aspx
    """

    @staticmethod
    def base_url():
        return "https://api.zhetaoke.com:10001/api/api_all.ashx"

    page: int = 1
    page_size: int = 20
    sort: str = "new"
    cid: Optional[int] = None

    #  券后价价格区间，
    #  值为空：全部商品，0.0-9.9：9.9元商品，0.0-19.9：19.9元商品
    price: str = "0.0-9.9"



from typing import List, Any, Optional, Union

from pydantic import BaseModel, Field


class CategoryGetSuperCategoryRespSubcategories(BaseModel):
    subcid: Optional[int] = Field(None)
    subcname: Optional[str] = Field(None)
    scpic: Optional[str] = Field(None)


class CategoryGetSuperCategoryResp(BaseModel):
    cid: Optional[Union[int, float]] = Field(None)
    cname: Optional[str] = Field(None)
    cpic: Optional[str] = Field(None)
    subcategories: Optional[List[CategoryGetSuperCategoryRespSubcategories]] = Field(
        None
    )


class GoodsPriceTrendRespHistoricalprice(BaseModel):
    actualPrice: Optional[float] = Field(None)
    date: Optional[str] = Field(None)


class GoodsPriceTrendResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    historicalPrice: Optional[List[GoodsPriceTrendRespHistoricalprice]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)


class GoodsGetDtkSearchGoodsRespList(BaseModel):
    id: Optional[int] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[int] = Field(None)
    goldSellers: Optional[int] = Field(None)
    monthSales: Optional[int] = Field(None)
    twoHoursSales: Optional[int] = Field(None)
    dailySales: Optional[int] = Field(None)
    commissionType: Optional[int] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[int] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[int] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    cid: Optional[int] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[int] = Field(None)
    haitao: Optional[int] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[int] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[int] = Field(None)
    brandId: Optional[int] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[int] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[int] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[list] = Field(None)
    quanMLink: Optional[int] = Field(None)
    hzQuanOver: Optional[int] = Field(None)
    yunfeixian: Optional[int] = Field(None)
    estimateAmount: Optional[int] = Field(None)
    freeshipRemoteDistrict: Optional[int] = Field(None)
    tbcid: Optional[int] = Field(None)


class GoodsGetDtkSearchGoodsResp(BaseModel):
    list: Optional[List[GoodsGetDtkSearchGoodsRespList]] = Field(None)
    totalNum: Optional[Union[int, float]] = Field(None)
    pageId: Optional[str] = Field(None)


class TbServiceGetPrivilegeLinkResp(BaseModel):
    couponClickUrl: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponInfo: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    itemId: Optional[str] = Field(None)
    couponTotalCount: Optional[str] = Field(None)
    couponRemainCount: Optional[str] = Field(None)
    itemUrl: Optional[str] = Field(None)
    tpwd: Optional[str] = Field(None)
    maxCommissionRate: Optional[str] = Field(None)
    shortUrl: Optional[str] = Field(None)
    minCommissionRate: Optional[str] = Field(None)
    longTpwd: Optional[str] = Field(None)


class GoodsGetRankingListResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    ranking: Optional[Union[int, float]] = Field(None)
    dtitle: Optional[str] = Field(None)
    actualPrice: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    hotPush: Optional[Union[int, float]] = Field(None)
    mainPic: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    desc: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    createTime: Optional[str] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    imgs: Optional[str] = Field(None)
    guideName: Optional[str] = Field(None)
    shopType: Optional[Union[int, float]] = Field(None)
    couponConditions: Optional[str] = Field(None)
    newRankingGoods: Optional[Union[int, float]] = Field(None)
    sellerId: Optional[str] = Field(None)
    quanMLink: Optional[Union[int, float]] = Field(None)
    hzQuanOver: Optional[Union[int, float]] = Field(None)
    yunfeixian: Optional[Union[int, float]] = Field(None)
    estimateAmount: Optional[Union[int, float]] = Field(None)
    freeshipRemoteDistrict: Optional[Union[int, float]] = Field(None)


class GoodsGetGoodsDetailsResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[Union[int, float]] = Field(None)
    goldSellers: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    brandWenan: Optional[str] = Field(None)
    cid: Optional[Union[int, float]] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    haitao: Optional[Union[int, float]] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[Union[int, float]] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[Union[int, float]] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[Union[int, float]] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[list] = Field(None)
    imgs: Optional[str] = Field(None)
    reimgs: Optional[str] = Field(None)
    quanMLink: Optional[Union[int, float]] = Field(None)
    hzQuanOver: Optional[Union[int, float]] = Field(None)
    yunfeixian: Optional[Union[int, float]] = Field(None)
    estimateAmount: Optional[Union[int, float]] = Field(None)
    shopLogo: Optional[str] = Field(None)
    specialText: Optional[list] = Field(None)
    freeshipRemoteDistrict: Optional[Union[int, float]] = Field(None)
    video: Optional[str] = Field(None)
    detailPics: Optional[str] = Field(None)
    isSubdivision: Optional[Union[int, float]] = Field(None)
    subdivisionId: Optional[Union[int, float]] = Field(None)
    subdivisionName: Optional[str] = Field(None)
    subdivisionRank: Optional[Union[int, float]] = Field(None)
    tbcid: Optional[Union[int, float]] = Field(None)


class TbServiceGetBrandListRespShop(BaseModel):
    name: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)


class TbServiceGetBrandListResp(BaseModel):
    cid: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    brandLogo: Optional[str] = Field(None)
    brandEnglish: Optional[str] = Field(None)
    shop: Optional[List[TbServiceGetBrandListRespShop]] = Field(None)
    brandScore: Optional[Union[int, float]] = Field(None)
    location: Optional[str] = Field(None)
    establishTime: Optional[str] = Field(None)
    belongTo: Optional[str] = Field(None)
    position: Optional[str] = Field(None)
    consumer: Optional[str] = Field(None)
    label: Optional[str] = Field(None)
    simpleLabel: Optional[str] = Field(None)
    cids: Optional[str] = Field(None)
    sales2h: Optional[Union[int, float]] = Field(None)
    fansNum: Optional[Union[int, float]] = Field(None)
    brandDesc: Optional[str] = Field(None)


class GoodsNineOpGoodsListRespList(BaseModel):
    id: Optional[int] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[int] = Field(None)
    goldSellers: Optional[int] = Field(None)
    monthSales: Optional[int] = Field(None)
    twoHoursSales: Optional[int] = Field(None)
    dailySales: Optional[int] = Field(None)
    commissionType: Optional[int] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[int] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[int] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    brandWenan: Optional[str] = Field(None)
    cid: Optional[int] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[int] = Field(None)
    haitao: Optional[int] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[int] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[int] = Field(None)
    brandId: Optional[int] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[int] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[int] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[list] = Field(None)
    nineCid: Optional[int] = Field(None)
    quanMLink: Optional[int] = Field(None)
    hzQuanOver: Optional[int] = Field(None)
    yunfeixian: Optional[int] = Field(None)
    estimateAmount: Optional[int] = Field(None)
    freeshipRemoteDistrict: Optional[int] = Field(None)
    video: Optional[str] = Field(None)
    tbcid: Optional[int] = Field(None)


class GoodsNineOpGoodsListResp(BaseModel):
    list: Optional[List[GoodsNineOpGoodsListRespList]] = Field(None)
    totalNum: Optional[Union[int, float]] = Field(None)
    pageId: Optional[str] = Field(None)


class TbServiceGetTbServiceRespSmall_images(BaseModel):
    string: Optional[List[str]] = Field(None)


class TbServiceGetTbServiceResp(BaseModel):
    title: Optional[str] = Field(None)
    volume: Optional[Union[int, float]] = Field(None)
    nick: Optional[str] = Field(None)
    coupon_start_time: Optional[str] = Field(None)
    coupon_end_time: Optional[str] = Field(None)
    tk_total_sales: Optional[str] = Field(None)
    coupon_id: Optional[str] = Field(None)
    pict_url: Optional[str] = Field(None)
    small_images: Optional[TbServiceGetTbServiceRespSmall_images] = Field(None)
    reserve_price: Optional[str] = Field(None)
    zk_final_price: Optional[str] = Field(None)
    user_type: Optional[Union[int, float]] = Field(None)
    commission_rate: Optional[str] = Field(None)
    seller_id: Optional[Union[int, float]] = Field(None)
    coupon_total_count: Optional[Union[int, float]] = Field(None)
    coupon_remain_count: Optional[Union[int, float]] = Field(None)
    coupon_info: Optional[str] = Field(None)
    shop_title: Optional[str] = Field(None)
    shop_dsr: Optional[Union[int, float]] = Field(None)
    level_one_category_name: Optional[str] = Field(None)
    level_one_category_id: Optional[Union[int, float]] = Field(None)
    category_name: Optional[str] = Field(None)
    category_id: Optional[Union[int, float]] = Field(None)
    short_title: Optional[str] = Field(None)
    white_image: Optional[str] = Field(None)
    coupon_start_fee: Optional[str] = Field(None)
    coupon_amount: Optional[str] = Field(None)
    item_description: Optional[str] = Field(None)
    item_id: Optional[Union[int, float]] = Field(None)
    ysyl_tlj_face: Optional[Union[int, float]] = Field(None)
    presale_deposit: Optional[Union[int, float]] = Field(None)
    presale_discount_fee_text: Optional[str] = Field(None)


class CategoryGetTop100Resp(BaseModel):
    hotWords: Optional[List[str]] = Field(None)


class GoodsGetGoodsListResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[Union[int, float]] = Field(None)
    goldSellers: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    brandWenan: Optional[str] = Field(None)
    cid: Optional[Union[int, float]] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    haitao: Optional[Union[int, float]] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[Union[int, float]] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[Union[int, float]] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[Union[int, float]] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[List[int]] = Field(None)
    quanMLink: Optional[Union[int, float]] = Field(None)
    hzQuanOver: Optional[Union[int, float]] = Field(None)
    yunfeixian: Optional[Union[int, float]] = Field(None)
    estimateAmount: Optional[Union[int, float]] = Field(None)
    shopLogo: Optional[str] = Field(None)
    specialText: Optional[List[str]] = Field(None)
    freeshipRemoteDistrict: Optional[Union[int, float]] = Field(None)
    video: Optional[str] = Field(None)
    tbcid: Optional[Union[int, float]] = Field(None)


class GoodsListSuperGoodsResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[Union[int, float]] = Field(None)
    goldSellers: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    brandWenan: Optional[str] = Field(None)
    cid: Optional[Union[int, float]] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    haitao: Optional[Union[int, float]] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[Union[int, float]] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[Union[int, float]] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[Union[int, float]] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[List[int]] = Field(None)
    quanMLink: Optional[Union[int, float]] = Field(None)
    hzQuanOver: Optional[Union[int, float]] = Field(None)
    yunfeixian: Optional[Union[int, float]] = Field(None)
    estimateAmount: Optional[Union[int, float]] = Field(None)
    tbcid: Optional[Union[int, float]] = Field(None)


class GoodsListSimilerGoodsByOpenResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[Union[int, float]] = Field(None)
    goldSellers: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    brandWenan: Optional[str] = Field(None)
    cid: Optional[Union[int, float]] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    haitao: Optional[Union[int, float]] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[Union[int, float]] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[Union[int, float]] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[Union[int, float]] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[List[int]] = Field(None)
    quanMLink: Optional[Union[int, float]] = Field(None)
    hzQuanOver: Optional[Union[int, float]] = Field(None)
    yunfeixian: Optional[Union[int, float]] = Field(None)
    estimateAmount: Optional[Union[int, float]] = Field(None)
    freeshipRemoteDistrict: Optional[Union[int, float]] = Field(None)
    tbcid: Optional[Union[int, float]] = Field(None)


class GoodsSearchSuggestionResp(BaseModel):
    kw: Optional[str] = Field(None)
    total: Optional[Union[int, float]] = Field(None)


class GoodsActivityCatalogueResp(BaseModel):
    activityId: Optional[Union[int, float]] = Field(None)
    activityName: Optional[str] = Field(None)
    startTime: Optional[str] = Field(None)
    endTime: Optional[str] = Field(None)
    goodsLabel: Optional[str] = Field(None)
    detailLabel: Optional[str] = Field(None)
    goodsType: Optional[Union[int, float]] = Field(None)


class GoodsTopicCatalogueResp(BaseModel):
    topicId: Optional[Union[int, float]] = Field(None)
    topicName: Optional[str] = Field(None)
    startTime: Optional[str] = Field(None)
    endTime: Optional[str] = Field(None)
    banner: Optional[List[str]] = Field(None)
    topBanner: Optional[List[str]] = Field(None)


class CategoryDdqGoodsListRespGoodslist(BaseModel):
    id: Optional[int] = Field(None)
    goodsId: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    cid: Optional[int] = Field(None)
    subcid: Optional[List[int]] = Field(None)
    ddqDesc: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    couponPrice: Optional[float] = Field(None)
    discounts: Optional[float] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponConditions: Optional[str] = Field(None)
    commissionType: Optional[int] = Field(None)
    commissionRate: Optional[float] = Field(None)
    createTime: Optional[str] = Field(None)
    couponReceiveNum: Optional[int] = Field(None)
    couponTotalNum: Optional[int] = Field(None)
    monthSales: Optional[int] = Field(None)
    activityType: Optional[int] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[int] = Field(None)
    sellerId: Optional[str] = Field(None)
    brand: Optional[int] = Field(None)
    brandId: Optional[int] = Field(None)
    brandName: Optional[str] = Field(None)
    twoHoursSales: Optional[int] = Field(None)
    dailySales: Optional[int] = Field(None)
    quanMLink: Optional[int] = Field(None)
    hzQuanOver: Optional[int] = Field(None)
    yunfeixian: Optional[int] = Field(None)
    estimateAmount: Optional[int] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    tbcid: Optional[int] = Field(None)


class CategoryDdqGoodsListRespRoundslist(BaseModel):
    ddqTime: Optional[str] = Field(None)
    status: Optional[int] = Field(None)


class CategoryDdqGoodsListResp(BaseModel):
    ddqTime: Optional[str] = Field(None)
    status: Optional[Union[int, float]] = Field(None)
    goodsList: Optional[List[CategoryDdqGoodsListRespGoodslist]] = Field(None)
    roundsList: Optional[List[CategoryDdqGoodsListRespRoundslist]] = Field(None)


class TbServiceParseTaokoulingRespOrigininfo(BaseModel):
    activityId: Optional[str] = Field(None)
    actualPrice: Optional[int] = Field(None)
    amount: Optional[int] = Field(None)
    endTime: Optional[str] = Field(None)
    image: Optional[str] = Field(None)
    pid: Optional[str] = Field(None)
    price: Optional[int] = Field(None)
    shopLogo: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    startFee: Optional[int] = Field(None)
    startTime: Optional[str] = Field(None)
    status: Optional[int] = Field(None)
    title: Optional[str] = Field(None)


class TbServiceParseTaokoulingResp(BaseModel):
    commissionRate: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[str] = Field(None)
    goodsId: Optional[str] = Field(None)
    originInfo: Optional[TbServiceParseTaokoulingRespOrigininfo] = Field(None)
    originType: Optional[str] = Field(None)
    originUrl: Optional[str] = Field(None)


class TbServiceCreatTaokoulingResp(BaseModel):
    password_simple: Optional[str] = Field(None)
    model: Optional[str] = Field(None)
    longTpwd: Optional[str] = Field(None)


class GoodsExclusiveGoodsListResp(BaseModel):
    id: int = Field(...)
    goodsId: str = Field(...)
    title: str = Field(...)
    dtitle: str = Field(...)
    originalPrice: float = Field(...)
    actualPrice: float = Field(...)
    shopType: int = Field(...)
    goldSellers: int = Field(...)
    monthSales: int = Field(...)
    twoHoursSales: int = Field(...)
    dailySales: int = Field(...)
    commissionType: int = Field(...)
    desc: str = Field(...)
    couponReceiveNum: int = Field(...)
    couponLink: str = Field(...)
    couponEndTime: str = Field(...)
    couponStartTime: str = Field(...)
    couponPrice: float = Field(...)
    couponConditions: str = Field(...)
    activityType: int = Field(...)
    createTime: str = Field(...)
    mainPic: str = Field(...)
    marketingMainPic: str = Field(...)
    sellerId: str = Field(...)
    cid: int = Field(...)
    discounts: float = Field(...)
    commissionRate: float = Field(...)
    couponTotalNum: int = Field(...)
    activityStartTime: str = Field(...)
    activityEndTime: str = Field(...)
    shopName: str = Field(...)
    shopLevel: int = Field(...)
    descScore: float = Field(...)
    brand: int = Field(...)
    brandId: int = Field(...)
    brandName: str = Field(...)
    hotPush: int = Field(...)
    teamName: str = Field(...)
    itemLink: str = Field(...)
    tchaoshi: int = Field(...)
    dsrScore: float = Field(...)
    dsrPercent: float = Field(...)
    shipScore: float = Field(...)
    shipPercent: float = Field(...)
    serviceScore: float = Field(...)
    servicePercent: float = Field(...)
    subcid: List[int] = Field(...)
    video: str = Field(...)
    quanMLink: int = Field(...)
    hzQuanOver: int = Field(...)
    yunfeixian: int = Field(...)
    estimateAmount: int = Field(...)
    freeshipRemoteDistrict: int = Field(...)
    specialText: list = Field(...)
    tbcid: int = Field(...)


class GoodsExplosiveGoodsListResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    dtitle: Optional[str] = Field(None)
    originalPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    shopType: Optional[Union[int, float]] = Field(None)
    goldSellers: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    twoHoursSales: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    desc: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponConditions: Optional[str] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    createTime: Optional[str] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    sellerId: Optional[str] = Field(None)
    cid: Optional[Union[int, float]] = Field(None)
    discounts: Optional[float] = Field(None)
    commissionRate: Optional[float] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    activityStartTime: Optional[str] = Field(None)
    activityEndTime: Optional[str] = Field(None)
    shopName: Optional[str] = Field(None)
    shopLevel: Optional[Union[int, float]] = Field(None)
    descScore: Optional[float] = Field(None)
    brand: Optional[Union[int, float]] = Field(None)
    brandId: Optional[Union[int, float]] = Field(None)
    brandName: Optional[str] = Field(None)
    hotPush: Optional[Union[int, float]] = Field(None)
    teamName: Optional[str] = Field(None)
    itemLink: Optional[str] = Field(None)
    tchaoshi: Optional[Union[int, float]] = Field(None)
    dsrScore: Optional[float] = Field(None)
    dsrPercent: Optional[float] = Field(None)
    shipScore: Optional[float] = Field(None)
    shipPercent: Optional[float] = Field(None)
    serviceScore: Optional[float] = Field(None)
    servicePercent: Optional[float] = Field(None)
    subcid: Optional[list] = Field(None)
    video: Optional[str] = Field(None)
    quanMLink: Optional[Union[int, float]] = Field(None)
    hzQuanOver: Optional[Union[int, float]] = Field(None)
    yunfeixian: Optional[Union[int, float]] = Field(None)
    estimateAmount: Optional[Union[int, float]] = Field(None)
    freeshipRemoteDistrict: Optional[Union[int, float]] = Field(None)
    specialText: Optional[List[str]] = Field(None)
    tbcid: Optional[Union[int, float]] = Field(None)


class DelanysBrandGetGoodsListResp(BaseModel):
    id: Optional[Union[int, float]] = Field(None)
    goodsId: Optional[str] = Field(None)
    cid: Optional[Union[int, float]] = Field(None)
    brandId: Optional[str] = Field(None)
    title: Optional[str] = Field(None)
    desc: Optional[str] = Field(None)
    specialText: Optional[list] = Field(None)
    commissionType: Optional[Union[int, float]] = Field(None)
    commissionRate: Optional[float] = Field(None)
    activityType: Optional[Union[int, float]] = Field(None)
    dailySales: Optional[Union[int, float]] = Field(None)
    monthSales: Optional[Union[int, float]] = Field(None)
    mainPic: Optional[str] = Field(None)
    marketingMainPic: Optional[str] = Field(None)
    video: Optional[str] = Field(None)
    originPrice: Optional[float] = Field(None)
    actualPrice: Optional[float] = Field(None)
    couponId: Optional[str] = Field(None)
    couponPrice: Optional[float] = Field(None)
    couponLink: Optional[str] = Field(None)
    couponConditions: Optional[str] = Field(None)
    couponReceiveNum: Optional[Union[int, float]] = Field(None)
    couponTotalNum: Optional[Union[int, float]] = Field(None)
    couponEndTime: Optional[str] = Field(None)
    couponStartTime: Optional[str] = Field(None)
    discount: Optional[float] = Field(None)
    freeshipRemoteDistrct: Optional[Union[int, float]] = Field(None)
    dTitle: Optional[str] = Field(None)


CategoryGetTbTopicListResp = Any
GoodsActivityGoodsListResp = Any
GoodsFirstOrderGiftMoneyResp = Any
GoodsFriendsCircleListResp = Any
GoodsGetCollectionListResp = Any
GoodsGetNewestGoodsResp = Any
GoodsGetOwnerGoodsResp = Any
GoodsGetStaleGoodsByTimeResp = Any
GoodsLivematerialGoodsListResp = Any
GoodsPullGoodsByTimeResp = Any
GoodsTopicCatalogue = Any
GoodsTopicGoodsListResp = Any
TbServiceActivityLinkResp = Any
TbServiceGetOrderDetailsResp = Any
TbServiceParseContentResp = Any
TbServiceTwdToTwdResp = Any



from datetime import datetime
from decimal import Decimal
from typing import Optional, Any, List

from pydantic import BaseModel

__all__ = ["OrderDetailsResp", "OrderDto", "TkStatusEnum"]


class TkStatusEnum(object):
    done = 3  # 订单结算
    paid = 12  # 订单付款
    cancel = 13  # 订单失效
    success = 14  # 确认收货


class OrderDto(BaseModel):
    # 订单在淘宝拍下付款的时间
    tb_paid_time: Optional[str] = None
    # 订单付款的时间，该时间同步淘宝，可能会略晚于买家在淘宝的订单创建时间
    tk_paid_time: Optional[str] = None
    # 买家确认收货的付款金额（不包含运费金额）
    # 这个大概率 是空字段 使用 alipay_total_price
    pay_price: Optional[str] = None
    # 结算预估收入 = 结算金额*提成。
    # 以买家确认收货的付款金额为基数，预估您可能获得的收入。
    # 因买家退款、您违规推广等原因，可能与您最终收入不一致。最终收入以月结后您实际收到的为准
    pub_share_fee: Optional[str] = None
    # 买家通过购物车购买的每个商品对应的订单编号，此订单编号并未在淘宝买家后台透出
    trade_id: Optional[str] = None
    # 二方：佣金收益的第一归属者； 三方：从其他淘宝客佣金中进行分成的推广者
    tk_order_role: Optional[int] = None
    # 订单确认收货后且商家完成佣金支付的时间
    tk_earning_time: Optional[str] = None
    # 推广位管理下的推广位名称对应的ID，同时也是pid=mm_1_2_3中的“3”这段数字
    adzone_id: Optional[str] = None
    # 从结算佣金中分得的收益比率
    pub_share_rate: Optional[str] = None
    # 维权标签，0 含义为非维权 1 含义为维权订单
    refund_tag: Optional[int] = None
    # 平台给与的补贴比率，如天猫、淘宝、聚划算等
    subsidy_rate: Optional[str] = None
    # 提成=收入比率*分成比率。指实际获得收益的比率
    tk_total_rate: Optional[str] = None
    # 商品所属的根类目，即一级类目的名称
    item_category_name: Optional[str] = None
    # 商家昵称
    seller_nick: Optional[str] = None
    # 推广者的会员id
    pub_id: Optional[int] = None
    # 推广者赚取佣金后支付给阿里妈妈的技术服务费用的比率
    alimama_rate: Optional[str] = None
    # 平台出资方，如天猫、淘宝、或聚划算等
    subsidy_type: Optional[str] = None
    # 商品图片
    item_img: Optional[str] = None
    # 付款预估收入=付款金额*提成。
    # 指买家付款金额为基数，预估您可能获得的收入。
    # 因买家退款等原因，可能与结算预估收入不一致
    pub_share_pre_fee: Optional[str] = None
    # 支付总额 买家拍下付款的金额（不包含运费金额）
    alipay_total_price: Optional[str] = None
    # 商品标题
    item_title: Optional[str] = None
    # 媒体管理下的对应ID的自定义名称
    site_name: Optional[str] = None
    # 商品数量
    item_num: Optional[int] = None
    # 补贴金额=结算金额*补贴比率
    subsidy_fee: Optional[str] = None
    # 技术服务费=结算金额*收入比率*技术服务费率。
    # 推广者赚取佣金后支付给阿里妈妈的技术服务费用
    alimama_share_fee: Optional[str] = None
    # 交易父 ID 买家在淘宝后台显示的订单编号
    # [用户可以看到的订单号码]
    trade_parent_id: Optional[str] = None
    # 订单所属平台类型，包括天猫、淘宝、聚划算等
    order_type: Optional[str] = None
    # 订单创建的时间，该时间同步淘宝，可能会略晚于买家在淘宝的订单创建时间
    tk_create_time: Optional[str] = None
    # 产品类型
    flow_source: Optional[str] = None
    # 成交平台
    terminal_type: Optional[str] = None
    # 通过推广链接达到商品、店铺详情页的点击时间
    click_time: Optional[str] = None
    # 淘宝客 状态
    # 已付款：指订单已付款，但还未确认收货
    # 已收货：指订单已确认收货，但商家佣金未支付
    # 已结算：指订单已确认收货，且商家佣金已支付成功
    # 已失效：指订单关闭/订单佣金小于0.01元，
    #   订单关闭主要有：
    #   1）买家超时未付款；
    #   2）买家付款前，买家/卖家取消了订单；
    #   3）订单付款后发起售中退款成功；
    #
    # 取值:
    #  3：订单结算，结算成功 [说明淘宝已经给这个订单结算了]
    # 12：订单付款， [用户已经付款]
    # 13：订单失效， [订单被取消 等]
    # 14：订单成功/确认收货
    tk_status: Optional[int] = None
    # 商品单价
    item_price: Optional[str] = None
    # 商品id
    item_id: Optional[int] = None
    # 推广位管理下的自定义推广位名称
    adzone_name: Optional[str] = None
    # 佣金比率
    total_commission_rate: Optional[str] = None
    # 商品的 URL 商品链接
    item_link: Optional[str] = None
    # 媒体管理下的ID，同时也是pid=mm_1_2_3中的“2”这段数字
    site_id: Optional[int] = None
    # 店铺名称
    seller_shop_title: Optional[str] = None
    # 订单结算的佣金比率+平台的补贴比率
    income_rate: Optional[str] = None
    # 佣金金额=结算金额＊佣金比率
    total_commission_fee: Optional[str] = None
    # 预估内容专项服务费：
    #   内容场景专项技术服务费，内容推广者在内容场景进行推广需要支付给阿里妈妈专项的技术服务费用。
    # 专项服务费＝付款金额＊专项服务费率。
    tk_commission_pre_fee_for_media_platform: Optional[str] = None
    # 结算内容专项服务费：
    #   内容场景专项技术服务费，内容推广者在内容场景进行推广需要支付给阿里妈妈专项的技术服务费用。
    # 专项服务费＝结算金额＊专项服务费率。
    tk_commission_fee_for_media_platform: Optional[str] = None
    # 内容专项服务费率：
    #   内容场景专项技术服务费率，
    #   内容推广者在内容场景进行推广需要按结算金额支付一定比例给阿里妈妈作为内容场景专项技术服务费，
    #   用于提供与内容平台实现产品技术对接等服务。
    tk_commission_rate_for_media_platform: Optional[str] = None
    # 会员运营id
    special_id: Optional[int] = None
    # 渠道关系id
    relation_id: Optional[int] = None
    # 预售时期，用户对预售商品支付定金的付款时间，可能略晚于在淘宝付定金时间
    tk_deposit_time: Optional[str] = None
    # 预售时期，用户对预售商品支付定金的付款时间
    tb_deposit_time: Optional[str] = None
    # 预售时期，用户对预售商品支付的定金金额
    deposit_price: Optional[str] = None
    # 开发者调用api的appkey
    app_key: Optional[str] = None
    # 口碑子订单号
    alsc_id: Optional[str] = None
    # 口碑父订单号
    alsc_pid: Optional[str] = None
    # 服务费信息
    service_fee_dto_list: Optional[Any] = None
    # 激励池对应的rid
    lx_rid: Optional[str] = None
    # 订单是否为激励池订单 1，表征是 0，表征否
    is_lx: Optional[str] = None

    def ali_pay_price(self) -> Optional[Decimal]:
        if self.alipay_total_price is None:
            return None
        return Decimal(self.alipay_total_price)

    def income(self) -> Optional[Decimal]:
        if self.pub_share_fee is not None:
            ret = Decimal(self.pub_share_fee)
            if ret >= 0.01:
                return ret

        if self.pub_share_pre_fee is None:
            return Decimal(0)
        return Decimal(self.pub_share_pre_fee)

    def order_ctime(self) -> Optional[datetime]:
        return self._str_to_datetime(self.tk_create_time)

    def end_time(self) -> Optional[datetime]:
        return self._str_to_datetime(self.tk_earning_time)

    def pay_time(self) -> Optional[datetime]:
        return self._str_to_datetime(self.tk_paid_time)

    @staticmethod
    def _str_to_datetime(s: Optional[str]) -> Optional[datetime]:
        if s is None:
            return None

        try:
            return datetime.strptime(s, "%Y-%m-%d %H:%M:%S")
        except ValueError:
            return None

    def order_platform(self) -> str:
        """
        获取订单的平台
        """
        if self.order_type is None:
            return "--"
        else:
            return self.order_type

    def is_order_canceled(self) -> bool:
        """
        订单失效/取消
        """
        return self.tk_status == TkStatusEnum.cancel

    def is_order_paid(self) -> bool:
        """
        订单已经付款
        """
        return self.tk_status == TkStatusEnum.paid

    def is_order_success(self) -> bool:
        """
        已经收货
        """
        return self.tk_status == TkStatusEnum.success

    def is_order_done(self) -> bool:
        """
        已经结算
        """
        return self.tk_status == TkStatusEnum.done


class OrderDetailsResp(BaseModel):
    has_next: bool
    has_pre: bool
    page_no: int
    page_size: int
    position_index: str
    # use get_order_lists 获取订单列表
    results: Optional[dict]

    @staticmethod
    def from_result(j: dict) -> Optional["OrderDetailsResp"]:
        resp = j["tbk_sc_order_details_get_response"]
        if "data" not in resp:
            return None

        data = resp["data"]
        if not isinstance(data, dict):
            return None

        if len(data["results"]) == 0:
            data["results"] = None

        return OrderDetailsResp(**data)

    def get_order_lists(self) -> List[OrderDto]:
        if not isinstance(self.results, dict):
            return []

        order_list = []
        if "publisher_order_dto" in self.results:
            order_list = self.results["publisher_order_dto"]

        return list(map(lambda x: OrderDto(**x), order_list))



"""
测试共享模块
"""
import os

from .gen import *


def get_app_key_and_secret() -> (str, str):
    app_key = os.getenv("DTK_APP_KEY")
    app_secret = os.getenv("DTK_APP_SECRET")
    if app_key is None or app_secret is None:
        with open(os.path.join(os.path.dirname(__file__), "..", "secret.json")) as fp:
            d = json.load(fp)
            app_key = d["app_key"]
            app_secret = d["app_secret"]
    return app_key, app_secret


def get_dtk_sync() -> DtkSync:
    app_key, app_secret = get_app_key_and_secret()
    return DtkSync(app_key=app_key, app_secret=app_secret)


def get_id() -> str:
    dtk = get_dtk_sync()
    args = GoodsGetDtkSearchGoodsArgs(keyWords="手机", pageId=str(1), pageSize=str(10))
    ret = dtk.goods_get_dtk_search_goods(args)
    assert ret["code"] == 0
    return ret["data"]["list"][0]["id"]


def get_uland_url() -> str:
    dtk = get_dtk_sync()
    goods_id = get_goods_id()
    args = GoodsGetGoodsDetailsArgs(id="", goodsId=goods_id)
    ret = dtk.goods_get_goods_details(args)
    return ret["data"]["couponLink"]


def get_goods_id() -> str:
    dtk = get_dtk_sync()
    args = GoodsGetDtkSearchGoodsArgs(keyWords="手机", pageId=str(1), pageSize=str(10))
    ret = dtk.goods_get_dtk_search_goods(args)
    assert ret["code"] == 0
    return ret["data"]["list"][0]["goodsId"]



import os
from urllib import parse

from pydantic import BaseModel


class BaseArgs(BaseModel):
    """
    折淘客基础请求数据类型

    子类的字段值为: None 的 key 会被过滤掉
    例如:
    f1: Optional[str] = None

    注意:
    字段值为 '' (空字符串) 的不会被过滤掉
    例如:
    f2: str = ''
    在个参数中会变成:
    'f2='
    """

    @staticmethod
    def base_url() -> str:
        raise NotImplementedError

    @staticmethod
    def ztk_app_key() -> str:
        """
        获取 折淘客的 app key
        """
        app_key = os.getenv("ZTK_APP_KEY", None)
        if app_key is not None:
            return app_key
        raise NotImplementedError

    def to_http_query(self, appkey: str) -> str:
        """
        转换成 HTTP 的查询字符串
        :param appkey:
        :return:
        """
        d = self.dict(by_alias=True)
        dks = []
        for k in d.keys():
            if d[k] is None:
                dks.append(k)

        for dk in dks:
            d.pop(dk)

        d["appkey"] = appkey
        return parse.urlencode(d)

    async def to_http_url(self) -> str:
        """
        转换成 HTTP 的请求 URL
        :return:
        """
        app_key = self.ztk_app_key()
        query = self.to_http_query(app_key)
        url = self.base_url()
        return f"{url}?{query}"

    def to_http_url_sync(self) -> str:
        """
        同步版本的 转换成 HTTP 请求
        :return:
        """
        app_key = self.ztk_app_key()
        query = self.to_http_query(app_key)
        url = self.base_url()
        return f"{url}?{query}"



import os

import pytest
from structlog.stdlib import get_logger

from .gao_yong_args import GaoYongArgs
from .guess_you_like_args import GuessYouLikeArgs
from .ztk_std import ZTKStd


def set_up_env():
    file = os.path.join(os.path.dirname(__file__), "../../dev.env")
    with open(file) as fp:
        lines = fp.readlines()
    for line in lines:
        line = line.strip()
        if line == "":
            continue
        if line.startswith("#"):
            continue
        parts = line.split("=")
        if len(parts) != 2:
            continue
        k, v = parts
        os.environ.setdefault(k, v)


@pytest.mark.asyncio
async def test_guess_you_like_and_gao_yong():
    set_up_env()

    logger = get_logger()
    sid = "49522"

    ztk = ZTKStd(ztk_sid=sid, logger=logger)
    args = GuessYouLikeArgs()
    ret = await ztk.guess_you_like(args)
    assert ret is not None

    item = ret[0]
    tao_id = item.tao_id
    pid = "mm_1612410100_2210750041_111118250414"
    args = GaoYongArgs(pid=pid, num_iid=tao_id, sid=sid)

    ret = await ztk.gao_yong(args)
    assert ret is not None
    print(ret)


@pytest.mark.asyncio
async def test_keyword():
    set_up_env()

    logger = get_logger()
    sid = "49522"

    ztk = ZTKStd(ztk_sid=sid, logger=logger)
    ret = await ztk.keyword()
    assert ret is not None
    print(ret)



from .base_args import BaseArgs


class ChannelAccountInfoArgs(BaseArgs):
    """
    淘宝客渠道信息查询API：获取渠道ID信息列表

    :doc https://www.zhetaoke.com/user/open/open_sc_publisher_get.aspx
    """

    @staticmethod
    def base_url() -> str:
        return "https://api.zhetaoke.com:10001/api/open_sc_publisher_get.ashx"

    #  渠道推广的物料类型，示例值：common
    relation_app: str

    #  渠道备案 - 渠道关系ID
    relation_id: int

    # 第几页
    page_no: int

    # 每页大小
    page_size: int

    #  类型，必选 默认为1
    info_type: int = 1

    sid: str = ""



from pydantic import BaseModel

__all__ = ["TopAuthTokenCreateTokenResult"]


class TopAuthTokenCreateTokenResult(BaseModel):
    w1_expires_in: int
    refresh_token_valid_time: int
    taobao_user_nick: str
    re_expires_in: int
    expire_time: int
    open_uid: str
    token_type: str
    access_token: str
    taobao_open_uid: str
    w1_valid: int
    refresh_token: str
    w2_expires_in: int
    w2_valid: int
    r1_expires_in: int
    r2_expires_in: int
    r2_valid: int
    r1_valid: int
    expires_in: int



from pydantic import BaseModel, Field

__all__ = ["TopAuthTokenCreateResp"]


class TopAuthTokenCreateResp(BaseModel):
    """
    获取Access Token

    doc: https://open.taobao.com/api.htm?docId=25388&docType=2
    """

    token_result: str = Field(
        ...,
        title="返回的是json信息",
        description="""
    和之前调用
    https://oauth.taobao.com/tac/token
    https://oauth.alibaba.com/token
    换token返回的字段信息一致

    参见: dt.TopAuthTokenCreateTokenResult
    """,
    )



from pydantic import Field

__all__ = ["page_field", "page_size_field", "cid_field", "sort_fields"]

token = Field(..., title="认证 TOKEN", description="用户用来认证的 token, 登陆的时候获取到的")
token_optional = Field(None, title="认证 TOKEN", description="用户用来认证的 token, 登陆的时候获取到的")

page_field = Field(1, gt=0, title="分页", description="第几页面")
page_size_field = Field(20, ge=10, le=50, title="每页数据条数", description="可自定义 10~50 之间")
cid_field = Field(
    None,
    title="一级商品分类",
    description="""一级商品分类
值为空：全部商品
1：女装
2：母婴
3：美妆
4：居家日用
5：鞋品
6：美食
7：文娱车品
8：数码家电
9：男装
10：内衣
11：箱包
12：配饰
13：户外运动
14：家装家纺
""",
)
sort_fields = Field(
    "new",
    title="商品排序方式",
    description="""
new：按照综合排序\n
total_sale_num_asc：按照总销量从小到大排序\n
total_sale_num_desc：按照总销量从大到小排序\n
sale_num_asc：按照月销量从小到大排序\n
sale_num_desc：按照月销量从大到小排序\n
commission_rate_asc：按照佣金比例从小到大排序\n
commission_rate_desc：按照佣金比例从大到小排序\n
price_asc：按照价格从小到大排序\n
price_desc：按照价格从大到小排序\n
coupon_info_money_asc：按照优惠券金额从小到大排序\n
coupon_info_money_desc：按照优惠券金额从大到小排序\n
shop_level_asc：按照店铺等级从低到高排序\n
shop_level_desc：按照店铺等级从高到低排序\n
tkfee_asc：按照返佣金额从低到高排序\n
tkfee_desc：按照返佣金额从高到低排序\n
code：按照code值从大到小排序\n
date_time：按照更新时间排序\n
random：按照随机排序\n
""",
)

code_field = Field(..., title="折淘客编号")
type_one_id_field = Field(..., title="分类 id, 参见: cid")
tao_id_field = Field(
    ..., title="淘宝的商品 id", description="都是同一个意思: item_id/num_iid/tao_id"
)
title_field = Field(..., title="商品的标题")
jianjie_field = Field(..., title="商品的简介")
pict_url_field = Field(..., title="商品的主图")
user_type_field = Field(..., title="卖家类型", description="0表示集市，1表示商城")
seller_id_field = Field(..., title="商家的 id")
shop_dsr_field = Field(..., title="店铺 dsr 评分")
volume_field = Field(..., title="30天销量")
size_field = Field(..., title="折扣价")
quanhou_jiage_field = Field(..., title="券后价格")
date_time_yongjin_field = Field(
    ..., title="数据更新时间", description="例如: 2020/06/25 20:35:46"
)
tkrate3_field = Field(..., title="佣金比例", description="例如: 25.00 表示 25.0%")
yongjin_type_field = Field(..., title="佣金类型", description="例如: MKT")
coupon_id_field = Field(..., title="优惠券ID", description="")
coupon_start_time_field = Field(..., title="优惠券开始时间", description="例如: 2020-10-10")
coupon_end_time_field = Field(..., title="优惠券结束时间", description="例如: 2020-10-10")
coupon_info_money_field = Field(..., title="优惠券金额", description="例如: 70.00 单位: 元")
coupon_total_count_field = Field(..., title="优惠券总量")
coupon_remain_count_field = Field(..., title="优惠券剩余数量")
coupon_info_field = Field(..., title="优惠券信息")
juhuasuan_field = Field(..., title="是否为 聚划算", description="0 否 1 是, 注意: 是字符串")
taoqianggou_field = Field(..., title="是否为 淘抢购", description="0 否 1 是, 注意: 是字符串")
haitao_field = Field(..., title="是否为 海淘", description="0 否 1 是, 注意: 是字符串")
jiyoujia_field = Field(..., title="是否极有家", description="0 否 1 是, 注意: 是字符串")
jinpaimaijia_field = Field(..., title="是否为 金牌卖家", description="0 否 1 是, 注意: 是字符串")
pinpai_field = Field(..., title="是否为 品牌", description="0 否 1 是, 注意: 是字符串")
pinpai_name_field = Field(..., title="品牌名称")
yunfeixian_feild = Field(..., title="是否有运费险", description="1有")
nick_field = Field(..., title="店铺名称")
small_images_field = Field(
    ..., title="商品组图/商品小图列表", description="商品组图, 为多个 url, 使用 | 分割"
)
white_image_field = Field(..., title="商品白底图")
tao_title_field = Field(..., title="商品长标题")
provcity_field = Field(..., title="省份 城市")
shop_title_field = Field(..., title="商家名称")
zhibo_url_field = Field(..., title="直播地址")
sellCount_field = Field(..., title="销售数量")
commentCount_field = Field(..., title="评论数量")
favcount_field = Field(..., title="喜欢数量")
score1_field = Field(..., title="宝贝描述分")
score2_field = Field(..., title="卖家服务分")
score3_field = Field(..., title="物流服务分")
creditLevel_field = Field(
    ...,
    title="店铺等级",
    description="""1-20:
一星 二星 三星 四星 五星
一钻 二钻 三钻 四钻 五钻
一皇冠 二皇冠 三皇冠 四皇冠 五皇冠
一金冠 二金冠 三金冠 四金冠 五金冠
""",
)
shopIcon_field = Field(..., title="商家图标 URL")
pcDescContent_field = Field(..., title="内容 url", description="多个 url 地址 使用 | 分隔开")
item_url_field = Field(..., title="商品地址")
category_id_field = Field(..., title="分类 id")
category_name_field = Field(..., title="分类名称")
level_one_category_id_field = Field(..., title="???")
level_one_category_name_field = Field(..., title="???")
tkfee3_field = Field(..., title="???")

volume_shishi_field = Field(..., title="两小时销量")
volume_quantian_field = Field(..., title="全天销量")
tk_sale_count_field = Field(..., title="人气值")
biaoqian_field = Field(..., title="店铺活动", description="满300元,省30元")
tag_field = Field(
    ...,
    title="朋友圈文案",
    description="例如: 赶紧拯救你厨房的油腻吧😂植护🌿加厚厨房抽纸高密度纤维纸张，吸油💧很不错5包装|￥14.8元💰✔厨房小帮手，用处多多",
)
presale_discount_fee_text_field = Field(
    None, title="预售商品-商品优惠信息", description="例如: 付定金立减20元"
)
presale_tail_end_time_field = Field(None, title="预售商品-付定金结束时间（毫秒）")
presale_tail_start_time_field = Field(None, title="预售商品-付尾款开始时间（毫秒）")
presale_end_time_field = Field(None, title="预售结束时间")
presale_start_time_field = Field(None, title="预售开始时间")
presale_deposit_field = Field(None, title="预售 ???")
yunfeixian_field = Field(..., title="???")

cat_leaf_name_field = Field(..., title="叶子类目名称", description="例如: 情趣内衣")
cat_name_field = Field(..., title="一级类目名称", description="例如: 女装")
ju_online_end_time_field = Field(..., title="聚划算信息-聚淘开始时间（毫秒）")
ju_online_start_time_field = Field(..., title="聚划算信息-聚淘结束时间（毫秒）")
ju_pre_show_end_time_field = Field(..., title="聚划算信息-商品预热结束时间（毫秒）")
ju_pre_show_start_time_field = Field(..., title="聚划算信息-商品预热开始时间（毫秒）")
material_lib_type_field = Field(
    ...,
    title="商品库类型",
    description="支持多库类型输出，以英文逗号分隔“,”分隔\n1:营销商品主推库\n2. 内容商品库，如果值为空则不属于1，2这两种商品类型",
)
num_iid_field = tao_id_field
reserve_price_field = Field(..., title="商品一口价格")
tmall_play_activity_end_time_field = Field(..., title="天猫限时抢可售 -结束时间（毫秒）")
tmall_play_activity_start_time_field = Field(..., title="天猫限时抢可售 -开始时间（毫秒）")
zk_final_price_field = Field(..., title="折扣价（元）若属于预售商品，付定金时间内，折扣价=预售价")
kuadian_promotion_info_field = Field(
    ..., title="跨店满减信息", description='例如: ["每100减20","每200减50"]'
)

date_time_field = Field(..., title="数据添加时间", description="")
min_commission_rate_field = Field(..., title="", description="")

order_type = Field(..., title="订单类型", description="")

taobao_url_field = Field(..., title="商品URL")
coupon_click_url_field = Field(..., title="二合一推广链接，已经自动拼接S券")
shorturl_field = Field(..., title="淘宝短链接")
tkl_field = Field(..., title="淘口令")



from typing import List, Dict, Optional

from pydantic import BaseModel, Field

__all__ = ["ProductGetArgs"]


class ProductGetArgs(BaseModel):
    """
    获取一个产品的信息

    doc: https://open.taobao.com/api.htm?docId=4&docType=2
    """

    product_id: Optional[int] = Field(
        None,
        title="Product的id",
        description="""
    两种方式来查看一个产品:
    1.传入product_id来查询
    2.传入cid和props来查询
    """,
    )

    cid: Optional[int] = Field(
        None,
        title="商品类目id",
        description="""

    调用taobao.itemcats.get获取;
    必须是叶子类目id,
    如果没有传product_id,那么cid和props必须要传.
    """,
    )

    #
    props: Optional[int] = Field(
        None,
        title="诺基亚N73这个产品的关键属性列表",
        description="品牌:诺基亚;型号:N73,对应的PV值就是10005:10027;10006:29729.",
    )

    method: str = Field("taobao.product.get", title="固定值")

    # 需要返回的字段列表，可选值为返回示例值中的可以看到的字段
    fields: List[str] = ("name", "binds", "product_id")

    def to_dict(self) -> Dict[str, str]:
        d = self.dict()
        d["fields"] = ",".join(d["fields"])
        return d



import logging
from logging import Logger
from typing import Optional

import requests

from .args import (
    UserSellerGetArgs,
    ProductGetArgs,
    TimeGetArgs,
    TopAuthTokenCreateArgs,
    TBKScPublisherInfoSaveArgs,
)
from .base_api import BaseApi
from .exceptions import TopHttpException
from .resp import TimeGetResp, TopAuthTokenCreateResp, TBKScPublisherInfoSaveResp

__all__ = ["TopApi"]


class TopApi(BaseApi):
    """
    阿里百川 Python SDK Sync Version
    """

    def __init__(self, app_key: str, app_secret: str, logger: Optional[Logger] = None):
        super().__init__(app_key, app_secret)
        self._session = requests.Session()
        self._logger = logging if logger is None else logger

    def user_seller_get(self, args: UserSellerGetArgs):
        url = self._to_url(args.to_dict())
        ret = self._do_request(url)
        print(ret)

    def product_get(self, args: ProductGetArgs):
        url = self._to_url(args.to_dict())
        ret = self._do_request(url)
        print(ret)

    def time_get(self) -> TimeGetResp:
        args = TimeGetArgs()
        ret = self._sync_request(args.dict(), args.method)
        return TimeGetResp(**ret)

    def top_auth_token_create(
        self, args: TopAuthTokenCreateArgs
    ) -> TopAuthTokenCreateResp:
        ret = self._sync_request(args.dict(), args.method)
        return TopAuthTokenCreateResp(**ret)

    def tbk_sc_publisher_info_save(
        self, args: TBKScPublisherInfoSaveArgs
    ) -> TBKScPublisherInfoSaveResp:
        ret = self._sync_request(args.dict(by_alias=True), args.method)
        self._logger.info(f"get ret: f{str(ret)}")
        data = ret["data"]
        self._logger.info(f"get data: f{str(data)}")
        return TBKScPublisherInfoSaveResp(**data)

    def _sync_request(self, args: dict, method: str) -> dict:
        """
        同步发送请求

        抛出的异常:
        TopHttpException, TopErrorRespException

        :param args:
        :param method:
        :return:
        """
        url = self._to_url(args)
        ret = self._do_request(url)
        return self._get_real_data(method, ret)

    def _do_request(self, url: str) -> dict:
        ret = self._session.get(url)
        if ret.ok:
            return ret.json()
        else:
            raise TopHttpException(str(ret))



from typing import Optional

import requests

from .mob_push_base import MobPushBase

__all__ = ["MobPushSyncApi"]


class MobPushSyncApi(MobPushBase):
    """
    Mob Push SDK (Sync version)

    :doc: https://www.mob.com/wiki/detailed/?wiki=MobPushRestAPIfenlei1333&id=136
    """

    g_session: Optional[requests.Session] = None

    def push_to_all(self, content: str):
        """
        推送给所有设备

        :doc: https://www.mob.com/wiki/detailed/?wiki=MobPushRestAPIfenlei1333&id=136

        :param content: 推送内容
        :return:
        """
        app_key = self._app_key

        data = {
            "source": "webapi",
            "appkey": app_key,
            "pushTarget": {
                "target": 1,  # 广播
            },
            "pushNotify": {
                "plats": [1],
                "content": content,
                "type": 1,
            },
        }

        self._do_push(data, app_key)

    def push(self, device: str, content: str, app_key: str):
        """
        推送一条消息

        :doc: https://www.mob.com/wiki/detailed/?wiki=MobPushRestAPIfenlei1333&id=136
        """
        data = {
            "source": "webapi",
            "appkey": app_key,
            "pushTarget": {
                "target": 4,
                "rids": [device],
            },
            "pushNotify": {
                "plats": [1],
                "content": content,
                "type": 1,
            },
        }

        self._do_push(data, app_key)

    def _do_push(self, data: dict, app_key: str):
        if self.g_session is None:
            self.g_session = requests.session()

        sign = self.sign_fun(data)
        headers = {"key": app_key, "sign": sign}

        ret = self.g_session.post(self.s_push_url, headers=headers, json=data)
        if ret.ok:
            j = ret.json()
            self._log.bind(data=data, ret=j).info("request mob push success")
        else:
            self._log.bind(data=data).error("request mob push failed")

    def sign_fun(self, data: Optional[dict]) -> str:
        """
        计算 mob 的签名

        :param data:
        :return:
        """
        return self.compute_sign(data)



from typing import Optional

from .base_args import BaseArgs


class AuthAccountArgs(BaseArgs):
    """
    获取账户授权列表API接口

    :doc https://www.zhetaoke.com/user/open/open_taokeshouquaninfo.aspx
    """

    @staticmethod
    def base_url() -> str:
        return " 接口地址：https://api.zhetaoke.com:10001/api/open_taokeshouquaninfo.ashx "

    #  第几页，每页最多返回100个
    page: Optional[int] = None

    #  还剩下几天授权过期，取值范围0-7之间的整数，
    #  比如值为3，表示获取还剩下3天授权过期淘客账号信息
    expire_day: Optional[int] = None

    # 对应的淘客账号授权ID
    sid: str = ""



import aiohttp

from .args import (
    UserSellerGetArgs,
    ProductGetArgs,
    TimeGetArgs,
    TopAuthTokenCreateArgs,
    TBKScPublisherInfoSaveArgs,
)
from .base_api import BaseApi
from .exceptions import TopHttpException
from .resp import TimeGetResp, TopAuthTokenCreateResp, TBKScPublisherInfoSaveResp

__all__ = ["AsyncTopApi"]


class AsyncTopApi(BaseApi):
    """
    阿里百川 Python SDK Async Version
    """

    def __init__(self, app_key: str, app_secret: str):
        super().__init__(app_key, app_secret)
        self._session = aiohttp.ClientSession()

    async def user_seller_get(self, args: UserSellerGetArgs):
        url = self._to_url(args.to_dict())
        ret = await self._do_request(url)
        print(ret)

    async def product_get(self, args: ProductGetArgs):
        url = self._to_url(args.to_dict())
        ret = await self._do_request(url)
        print(ret)

    async def time_get(self) -> TimeGetResp:
        args = TimeGetArgs()
        ret = await self._async_request(args.dict(), args.method)
        return TimeGetResp(**ret)

    async def top_auth_token_create(
        self, args: TopAuthTokenCreateArgs
    ) -> TopAuthTokenCreateResp:
        ret = await self._async_request(args.dict(), args.method)
        return TopAuthTokenCreateResp(**ret)

    async def tbk_sc_publisher_info_save(
        self, args: TBKScPublisherInfoSaveArgs
    ) -> TBKScPublisherInfoSaveResp:
        ret = await self._async_request(args.dict(by_alias=True), args.method)
        return TBKScPublisherInfoSaveResp(**ret)

    async def _async_request(self, args: dict, method: str):
        """
        同步发送请求

        抛出的异常:
        TopHttpException, TopErrorRespException

        :param args:
        :param method:
        :return:
        """
        url = self._to_url(args)
        ret = await self._do_request(url)
        return self._get_real_data(method, ret)

    async def _do_request(self, url: str) -> dict:
        ret = await self._session.get(url)
        if 200 <= ret.status < 300:
            return await ret.json()
        else:
            raise TopHttpException(str(ret))
